//==============================================================================
//
//  SRU.h (c) Copyright 2006 Analog Devices, Inc.  All rights reserved.
//
//  This include file contains a list of macro "defines" to enable the
//  programmer to use symbolic names for ADSP-21375/1 SRU
//  This is intended to simplify patching in the Signal Routing Unit (SRU)
//  The SRU macro is as follows: SRU(OUT,IN)
//
//  02.APR.06 - RC - Created initial version
//  ============================================================================
#ifndef __SRU21375_H_
#define __SRU21375_H_

// ================================================================================
// Uncomment the following definition for SRUDEBUG, or add SRUDEBUG to preprocessor
// definitions in project options or source file for the Assembler/Compiler to allow
// the SRU macro to check its inputs for validity. Without this check, it is possible
// to have an errorless/warningless build that did not have valid signals routed
// according to the groupings in the 2136x Hardware Reference, caused by invalid user
// input.
//
// Enabling error checking increases the memory used by the macro. Once the routings
// are verified, it is no longer necessary to enable the error checking mechanism.
// ================================================================================
//#define SRUDEBUG

// We need the following header file for the SRU register address definitions
#ifndef __DEF21375_H_
#include <def21375.h>
#endif

#ifndef SRUDEBUG
//==============================================================================
//  Macro: SRU
//  Reads, modifies and writes back a particular SRU register to change a single
//  SRU assignment (i.e. selects an input to an output).
//==============================================================================

#ifdef _LANGUAGE_C
#define SRU(out,in)                      \
  * (volatile unsigned int *) in##_REG = (sru_field(out,in) | (* (volatile unsigned int *) in##_REG & sru_mask(out,in)));
#else

#define SRU(out,in)         \
    r0=dm(in##_REG);       \
    r1=sru_mask(out,in);    \
    r0=r0 and r1;           \
    r1=sru_field(out,in);   \
    r0=r0 or r1;            \
    dm(in##_REG)=r0;
#endif

#else
//==============================================================================
//  Macro: SRU with error checking
//  Checks for incompatible input and output selections. Valid routings will
//  read, modify and write back a particular SRU register to change a single
//  SRU assignment (i.e. selects an input to an output).
//  Invalid routings will hang infinitely with the PC pointing to the offending
//  routing code.
//  The compiler will generate warnings for unreachable code when the routing is
//  invalid.
//==============================================================================
#ifdef _LANGUAGE_C
static volatile int sru_routing_error;
#define SRU(out,in)                      \
  SRU_ERROR_CHECK(out,in) \
  * (volatile unsigned int *) in##_REG = (sru_field(out,in) | (* (volatile unsigned int *) in##_REG & sru_mask(out,in)));

#define SRU_ERROR_CHECK(out,in) \
  if(!sru_check(out,in)) \
  { \
      sru_routing_error=1;\
      while(1){;} \
  }

#else

#define SRU(out,in)         \
    SRU_ERROR_CHECK(out,in) \
    r0=dm(in##_REG);       \
    r1=sru_mask(out,in);    \
    r0=r0 and r1;           \
    r1=sru_field(out,in);   \
    r0=r0 or r1;            \
    dm(in##_REG)=r0;

#define SRU_ERROR_CHECK(out,in) \
    r1=sru_check(out,in); \
    r1 = pass r1; \
    if ne jump(pc,2); \
    ILLEGAL_ROUTING_DETECTED?:\
    jump(pc,0);
#endif

#endif

#define SRU2(out,in)   SRU(out,in)


//==============================================================================
//  Macro: sru_field
//  Creates the bit field for a given input and output signal.
//==============================================================================
#define sru_field(out,in) \
    (((in##_GROUP & GROUP_A) >> LOG_GROUP_A) * A_##out \
    |((in##_GROUP & GROUP_B) >> LOG_GROUP_B) * B_##out \
    |((in##_GROUP & GROUP_C) >> LOG_GROUP_C) * C_##out \
    |((in##_GROUP & GROUP_D) >> LOG_GROUP_D) * D_##out \
    |((in##_GROUP & GROUP_E) >> LOG_GROUP_E) * E_##out \
    |((in##_GROUP & GROUP_F) >> LOG_GROUP_F) * F_##out \
    |((in##_GROUP & GROUP_G) >> LOG_GROUP_G) * G_##out \
    |((in##_GROUP & GROUP_A2)>> LOG_GROUP_A2)* A2_##out \
    |((in##_GROUP & GROUP_B2)>> LOG_GROUP_B2)* B2_##out \
    |((in##_GROUP & GROUP_C2)>> LOG_GROUP_C2)* C2_##out ) << in##_SHIFT

//==============================================================================
//  Macro: sru_mask
//  Creates a mask which can be used for clearing the bitfield belonging
//  to the given input and output signal.
//==============================================================================
#define sru_mask(out,in) \
     ~((((in##_GROUP & GROUP_A) >> LOG_GROUP_A) * MASK_A \
       |((in##_GROUP & GROUP_B) >> LOG_GROUP_B) * MASK_B \
       |((in##_GROUP & GROUP_C) >> LOG_GROUP_C) * MASK_C \
       |((in##_GROUP & GROUP_D) >> LOG_GROUP_D) * MASK_D \
       |((in##_GROUP & GROUP_E) >> LOG_GROUP_E) * MASK_E \
       |((in##_GROUP & GROUP_F) >> LOG_GROUP_F) * MASK_F \
       |((in##_GROUP & GROUP_G) >> LOG_GROUP_G) * MASK_G \
       |((in##_GROUP & GROUP_A2)>> LOG_GROUP_A2)* MASK_A2\
       |((in##_GROUP & GROUP_B2)>> LOG_GROUP_B2)* MASK_B2\
       |((in##_GROUP & GROUP_C2)>> LOG_GROUP_C2)* MASK_C2) << in##_SHIFT)


//==============================================================================
//  Macro: sru_check
//  Creates the bit field for a given input and output signal to test for errors.
//  Returns 0 if the routing is invalid
//==============================================================================
#define sru_check(out,in) \
    ((((in##_GROUP & GROUP_A) >> LOG_GROUP_A)*0xFF) & ~A_##out \
    |(((in##_GROUP & GROUP_B) >> LOG_GROUP_B)*0xFF) & ~B_##out \
    |(((in##_GROUP & GROUP_C) >> LOG_GROUP_C)*0xFF) & ~C_##out \
    |(((in##_GROUP & GROUP_D) >> LOG_GROUP_D)*0xFF) & ~D_##out \
    |(((in##_GROUP & GROUP_E) >> LOG_GROUP_E)*0xFF) & ~E_##out \
    |(((in##_GROUP & GROUP_F) >> LOG_GROUP_F)*0xFF) & ~F_##out \
    |(((in##_GROUP & GROUP_G) >> LOG_GROUP_G)*0xFF) & ~G_##out \
    |(((in##_GROUP & GROUP_A2)>> LOG_GROUP_A2)*0xFF) & ~A2_##out \
    |(((in##_GROUP & GROUP_B2)>> LOG_GROUP_B2)*0xFF) & ~B2_##out \
    |(((in##_GROUP & GROUP_C2)>> LOG_GROUP_C2)*0xFF) & ~C2_##out )


// Logarithm of Group ID Numbers
#define LOG_GROUP_A     0
#define LOG_GROUP_B     1
#define LOG_GROUP_C     2
#define LOG_GROUP_D     3
#define LOG_GROUP_E     4
#define LOG_GROUP_F     5
#define LOG_GROUP_G     6
#define LOG_GROUP_A2    7
#define LOG_GROUP_B2    8
#define LOG_GROUP_C2    9


// Group ID numbers
#define GROUP_A         (0x01 << LOG_GROUP_A)
#define GROUP_B         (0x01 << LOG_GROUP_B)
#define GROUP_C         (0x01 << LOG_GROUP_C)
#define GROUP_D         (0x01 << LOG_GROUP_D)
#define GROUP_E         (0x01 << LOG_GROUP_E)
#define GROUP_F         (0x01 << LOG_GROUP_F)
#define GROUP_G         (0x01 << LOG_GROUP_G)
#define GROUP_A2        (0x01 << LOG_GROUP_A2)
#define GROUP_B2        (0x01 << LOG_GROUP_B2)
#define GROUP_C2        (0x01 << LOG_GROUP_C2)

// Group Base Masks
// The actual field masks can be computed by shifting them to the proper
// location
#define MASK_A          0x1f
#define MASK_B          0x3f
#define MASK_C          0x1f
#define MASK_D          0x7f
#define MASK_E          0x1f
#define MASK_F          0x3f
#define MASK_G          0x01
#define MASK_A2         0x1f
#define MASK_B2         0x3f
#define MASK_C2         0x3f


//==============================================================================
//  Group A - Serial Clock Signals
//==============================================================================

//--------------------------------------------
//  Group ID Assignments
//--------------------------------------------
#define SPORT0_CLK_I_GROUP      GROUP_A
#define SPORT1_CLK_I_GROUP      GROUP_A
#define SPORT2_CLK_I_GROUP      GROUP_A
#define SPORT3_CLK_I_GROUP      GROUP_A

#define DIT_CLK_I_GROUP         GROUP_A

#define PDAP_CLK_I_GROUP        GROUP_A
#define IDP0_CLK_I_GROUP        GROUP_A
#define IDP1_CLK_I_GROUP        GROUP_A
#define IDP2_CLK_I_GROUP        GROUP_A

#define IDP3_CLK_I_GROUP        GROUP_A
#define IDP4_CLK_I_GROUP        GROUP_A
#define IDP5_CLK_I_GROUP        GROUP_A
#define IDP6_CLK_I_GROUP        GROUP_A
#define IDP7_CLK_I_GROUP        GROUP_A

#define DIT_HFCLK_I_GROUP       GROUP_A

#define PCG_EXTA_I_GROUP        GROUP_A
#define PCG_EXTB_I_GROUP        GROUP_A

#define PCG_SYNC_CLKA_I_GROUP   GROUP_A
#define PCG_SYNC_CLKB_I_GROUP   GROUP_A

#define PCG_SYNC_CLKC_I_GROUP   GROUP_A
#define PCG_SYNC_CLKD_I_GROUP   GROUP_A

#define PCG_EXTC_I_GROUP        GROUP_A
#define PCG_EXTD_I_GROUP        GROUP_A

//--------------------------------------------
//  Register Assignments
//--------------------------------------------
#define SPORT0_CLK_I_REG        SRU_CLK0
#define SPORT1_CLK_I_REG        SRU_CLK0
#define SPORT2_CLK_I_REG        SRU_CLK0
#define SPORT3_CLK_I_REG        SRU_CLK0

#define DIT_CLK_I_REG           SRU_CLK2
#define PDAP_CLK_I_REG          SRU_CLK2
#define IDP0_CLK_I_REG          SRU_CLK2
#define IDP1_CLK_I_REG          SRU_CLK2
#define IDP2_CLK_I_REG          SRU_CLK2

#define IDP3_CLK_I_REG          SRU_CLK3
#define IDP4_CLK_I_REG          SRU_CLK3
#define IDP5_CLK_I_REG          SRU_CLK3
#define IDP6_CLK_I_REG          SRU_CLK3
#define IDP7_CLK_I_REG          SRU_CLK3
#define DIT_HFCLK_I_REG         SRU_CLK3

#define PCG_EXTA_I_REG          SRU_CLK4
#define PCG_EXTB_I_REG          SRU_CLK4

#define PCG_SYNC_CLKA_I_REG     SRU_CLK4
#define PCG_SYNC_CLKB_I_REG     SRU_CLK4

#define PCG_SYNC_CLKC_I_REG     SRU_CLK5
#define PCG_SYNC_CLKD_I_REG     SRU_CLK5
#define PCG_EXTC_I_REG          SRU_CLK5
#define PCG_EXTD_I_REG          SRU_CLK5

//--------------------------------------------
//  Shift Values for Bit Fields
//--------------------------------------------

// SRU_CLK0
#define SPORT0_CLK_I_SHIFT      0
#define SPORT1_CLK_I_SHIFT      5
#define SPORT2_CLK_I_SHIFT      10
#define SPORT3_CLK_I_SHIFT      15

// SRU_CLK2
#define SRC3_CLK_IP_I_SHIFT     0
#define SRC3_CLK_OP_I_SHIFT     5
#define DIT_CLK_I_SHIFT         10
#define PDAP_CLK_I_SHIFT        15
#define IDP0_CLK_I_SHIFT        15
#define IDP1_CLK_I_SHIFT        20
#define IDP2_CLK_I_SHIFT        25

// SRU_CLK3
#define IDP3_CLK_I_SHIFT        0
#define IDP4_CLK_I_SHIFT        5
#define IDP5_CLK_I_SHIFT        10
#define IDP6_CLK_I_SHIFT        15
#define IDP7_CLK_I_SHIFT        20
#define DIT_HFCLK_I_SHIFT       25

// SRU_CLK4
#define PCG_EXTA_I_SHIFT        0
#define PCG_EXTB_I_SHIFT        5

#define PCG_SYNC_CLKA_I_SHIFT   20
#define PCG_SYNC_CLKB_I_SHIFT   25

// SRU_CLK5
#define PCG_SYNC_CLKC_I_SHIFT   10
#define PCG_SYNC_CLKD_I_SHIFT   15
#define PCG_EXTC_I_SHIFT        20
#define PCG_EXTD_I_SHIFT        25

//--------------------------------------------
//  Bit Field Codes
//--------------------------------------------
#define A_DAI_PB01_O            0x00
#define A_DAI_PB02_O            0x01
#define A_DAI_PB03_O            0x02
#define A_DAI_PB04_O            0x03
#define A_DAI_PB05_O            0x04
#define A_DAI_PB06_O            0x05
#define A_DAI_PB07_O            0x06
#define A_DAI_PB08_O            0x07
#define A_DAI_PB09_O            0x08
#define A_DAI_PB10_O            0x09
#define A_DAI_PB11_O            0x0a
#define A_DAI_PB12_O            0x0b
#define A_DAI_PB13_O            0x0c
#define A_DAI_PB14_O            0x0d
#define A_DAI_PB15_O            0x0e
#define A_DAI_PB16_O            0x0f
#define A_DAI_PB17_O            0x10
#define A_DAI_PB18_O            0x11
#define A_DAI_PB19_O            0x12
#define A_DAI_PB20_O            0x13
#define A_SPORT0_CLK_O          0x14
#define A_SPORT1_CLK_O          0x15
#define A_SPORT2_CLK_O          0x16
#define A_SPORT3_CLK_O          0x17
#define A_DIR_CLK_O             0x1a
#define A_DIR_TDMCLK_O          0x1b
#define A_PCG_CLKA_O            0x1c
#define A_PCG_CLKB_O            0x1d
#define A_LOW                   0x1e
#define A_HIGH                  0x1f

//==============================================================================
//  Group B - Serial Data Signals
//==============================================================================

//--------------------------------------------
//  Group ID Assignments
//--------------------------------------------
#define SPORT0_DA_I_GROUP       GROUP_B
#define SPORT0_DB_I_GROUP       GROUP_B
#define SPORT1_DA_I_GROUP       GROUP_B
#define SPORT1_DB_I_GROUP       GROUP_B
#define SPORT2_DA_I_GROUP       GROUP_B
#define SPORT2_DB_I_GROUP       GROUP_B

#define SPORT3_DA_I_GROUP       GROUP_B
#define SPORT3_DB_I_GROUP       GROUP_B

#define DIT_DAT_I_GROUP         GROUP_B
#define IDP0_DAT_I_GROUP        GROUP_B
#define IDP1_DAT_I_GROUP        GROUP_B
#define IDP2_DAT_I_GROUP        GROUP_B
#define IDP3_DAT_I_GROUP        GROUP_B
#define IDP4_DAT_I_GROUP        GROUP_B
#define IDP5_DAT_I_GROUP        GROUP_B
#define IDP6_DAT_I_GROUP        GROUP_B
#define IDP7_DAT_I_GROUP        GROUP_B

#define DIR_I_GROUP             GROUP_B

//--------------------------------------------
//  Register Assignments
//--------------------------------------------
#define SPORT0_DA_I_REG         SRU_DAT0
#define SPORT0_DB_I_REG         SRU_DAT0
#define SPORT1_DA_I_REG         SRU_DAT0
#define SPORT1_DB_I_REG         SRU_DAT0
#define SPORT2_DA_I_REG         SRU_DAT0

#define SPORT2_DB_I_REG         SRU_DAT1
#define SPORT3_DA_I_REG         SRU_DAT1
#define SPORT3_DB_I_REG         SRU_DAT1

#define DIT_DAT_I_REG           SRU_DAT4
#define IDP0_DAT_I_REG          SRU_DAT4
#define IDP1_DAT_I_REG          SRU_DAT4
#define IDP2_DAT_I_REG          SRU_DAT4
#define IDP3_DAT_I_REG          SRU_DAT4

#define IDP4_DAT_I_REG          SRU_DAT5
#define IDP5_DAT_I_REG          SRU_DAT5
#define IDP6_DAT_I_REG          SRU_DAT5
#define IDP7_DAT_I_REG          SRU_DAT5
#define DIR_I_REG               SRU_DAT5

//--------------------------------------------
//  Shift Values for Bit Fields
//--------------------------------------------

// SRU_DAT0
#define SPORT0_DA_I_SHIFT       0
#define SPORT0_DB_I_SHIFT       6
#define SPORT1_DA_I_SHIFT       12
#define SPORT1_DB_I_SHIFT       18
#define SPORT2_DA_I_SHIFT       24

// SRU_DAT1
#define SPORT2_DB_I_SHIFT       0
#define SPORT3_DA_I_SHIFT       6
#define SPORT3_DB_I_SHIFT       12

// SRU_DAT2

//SRU DAT3

// SRU_DAT4
#define DIT_DAT_I_SHIFT         0
#define IDP0_DAT_I_SHIFT        6
#define IDP1_DAT_I_SHIFT        12
#define IDP2_DAT_I_SHIFT        18
#define IDP3_DAT_I_SHIFT        24

// SRU_DAT5
#define IDP4_DAT_I_SHIFT        0
#define IDP5_DAT_I_SHIFT        6
#define IDP6_DAT_I_SHIFT        12
#define IDP7_DAT_I_SHIFT        18
#define DIR_I_SHIFT             24

// SRU_DAT6

//--------------------------------------------
//  Bit Field Codes
//--------------------------------------------
#define B_DAI_PB01_O            0x00
#define B_DAI_PB02_O            0x01
#define B_DAI_PB03_O            0x02
#define B_DAI_PB04_O            0x03
#define B_DAI_PB05_O            0x04
#define B_DAI_PB06_O            0x05
#define B_DAI_PB07_O            0x06
#define B_DAI_PB08_O            0x07
#define B_DAI_PB09_O            0x08
#define B_DAI_PB10_O            0x09
#define B_DAI_PB11_O            0x0a
#define B_DAI_PB12_O            0x0b
#define B_DAI_PB13_O            0x0c
#define B_DAI_PB14_O            0x0d
#define B_DAI_PB15_O            0x0e
#define B_DAI_PB16_O            0x0f
#define B_DAI_PB17_O            0x10
#define B_DAI_PB18_O            0x11
#define B_DAI_PB19_O            0x12
#define B_DAI_PB20_O            0x13
#define B_SPORT0_DA_O           0x14
#define B_SPORT0_DB_O           0x15
#define B_SPORT1_DA_O           0x16
#define B_SPORT1_DB_O           0x17
#define B_SPORT2_DA_O           0x18
#define B_SPORT2_DB_O           0x19
#define B_SPORT3_DA_O           0x1a
#define B_SPORT3_DB_O           0x1b
#define B_DIR_DAT_O             0x28
#define B_DIT_O                 0x30
#define B_LOW                   0x3e
#define B_HIGH                  0x3f

//==============================================================================
//  Group C - Fame Sync Signals
//==============================================================================

//--------------------------------------------
//  Group ID Assignments
//--------------------------------------------
#define SPORT0_FS_I_GROUP       GROUP_C
#define SPORT1_FS_I_GROUP       GROUP_C
#define SPORT2_FS_I_GROUP       GROUP_C
#define SPORT3_FS_I_GROUP       GROUP_C

#define DIT_FS_I_GROUP          GROUP_C
#define PDAP_HOLD_I_GROUP       GROUP_C
#define IDP0_FS_I_GROUP         GROUP_C
#define IDP1_FS_I_GROUP         GROUP_C
#define IDP2_FS_I_GROUP         GROUP_C

#define IDP3_FS_I_GROUP         GROUP_C
#define IDP4_FS_I_GROUP         GROUP_C
#define IDP5_FS_I_GROUP         GROUP_C
#define IDP6_FS_I_GROUP         GROUP_C
#define IDP7_FS_I_GROUP         GROUP_C

//--------------------------------------------
//  Register Assignments
//--------------------------------------------
#define SPORT0_FS_I_REG         SRU_FS0
#define SPORT1_FS_I_REG         SRU_FS0
#define SPORT2_FS_I_REG         SRU_FS0
#define SPORT3_FS_I_REG         SRU_FS0

#define DIT_FS_I_REG            SRU_FS2
#define PDAP_HOLD_I_REG         SRU_FS2
#define IDP0_FS_I_REG           SRU_FS2
#define IDP1_FS_I_REG           SRU_FS2
#define IDP2_FS_I_REG           SRU_FS2

#define IDP3_FS_I_REG           SRU_FS3
#define IDP4_FS_I_REG           SRU_FS3
#define IDP5_FS_I_REG           SRU_FS3
#define IDP6_FS_I_REG           SRU_FS3
#define IDP7_FS_I_REG           SRU_FS3

//--------------------------------------------
//  Shift Values for Bit Fields
//--------------------------------------------

// SRU_FS0
#define SPORT0_FS_I_SHIFT       0
#define SPORT1_FS_I_SHIFT       5
#define SPORT2_FS_I_SHIFT       10
#define SPORT3_FS_I_SHIFT       15

// SRU_FS1

// SRU_FS2
#define DIT_FS_I_SHIFT          10
#define PDAP_HOLD_I_SHIFT       15
#define IDP0_FS_I_SHIFT         15
#define IDP1_FS_I_SHIFT         20
#define IDP2_FS_I_SHIFT         25


// SRU_FS3
#define IDP3_FS_I_SHIFT         0
#define IDP4_FS_I_SHIFT         5
#define IDP5_FS_I_SHIFT         10
#define IDP6_FS_I_SHIFT         15
#define IDP7_FS_I_SHIFT         20

//SRU_FS4

//--------------------------------------------
//  Bit Field Codes
//--------------------------------------------
#define C_DAI_PB01_O            0x00
#define C_DAI_PB02_O            0x01
#define C_DAI_PB03_O            0x02
#define C_DAI_PB04_O            0x03
#define C_DAI_PB05_O            0x04
#define C_DAI_PB06_O            0x05
#define C_DAI_PB07_O            0x06
#define C_DAI_PB08_O            0x07
#define C_DAI_PB09_O            0x08
#define C_DAI_PB10_O            0x09
#define C_DAI_PB11_O            0x0a
#define C_DAI_PB12_O            0x0b
#define C_DAI_PB13_O            0x0c
#define C_DAI_PB14_O            0x0d
#define C_DAI_PB15_O            0x0e
#define C_DAI_PB16_O            0x0f
#define C_DAI_PB17_O            0x10
#define C_DAI_PB18_O            0x11
#define C_DAI_PB19_O            0x12
#define C_DAI_PB20_O            0x13
#define C_SPORT0_FS_O           0x14
#define C_SPORT1_FS_O           0x15
#define C_SPORT2_FS_O           0x16
#define C_SPORT3_FS_O           0x17
#define C_DIR_FS_O              0x1a

#define C_PCG_FSA_O             0x1c
#define C_PCG_FSB_O             0x1d
#define C_LOW                   0x1e
#define C_HIGH                  0x1f

//==============================================================================
//  Group D - Pin Input Signals
//==============================================================================

//--------------------------------------------
//  Group ID Assignments
//--------------------------------------------
#define DAI_PB01_I_GROUP        GROUP_D
#define DAI_PB02_I_GROUP        GROUP_D
#define DAI_PB03_I_GROUP        GROUP_D
#define DAI_PB04_I_GROUP        GROUP_D
#define DAI_PB05_I_GROUP        GROUP_D

#define DAI_PB06_I_GROUP        GROUP_D
#define DAI_PB07_I_GROUP        GROUP_D
#define DAI_PB08_I_GROUP        GROUP_D
#define DAI_PB09_I_GROUP        GROUP_D
#define DAI_PB10_I_GROUP        GROUP_D

#define DAI_PB11_I_GROUP        GROUP_D
#define DAI_PB12_I_GROUP        GROUP_D
#define DAI_PB13_I_GROUP        GROUP_D
#define DAI_PB14_I_GROUP        GROUP_D
#define DAI_PB15_I_GROUP        GROUP_D

#define DAI_PB16_I_GROUP        GROUP_D
#define DAI_PB17_I_GROUP        GROUP_D
#define DAI_PB18_I_GROUP        GROUP_D
#define DAI_PB19_I_GROUP        GROUP_D
#define DAI_PB20_I_GROUP        GROUP_D


//--------------------------------------------
//  Register Assignments
//--------------------------------------------
#define DAI_PB01_I_REG          SRU_PIN0
#define DAI_PB02_I_REG          SRU_PIN0
#define DAI_PB03_I_REG          SRU_PIN0
#define DAI_PB04_I_REG          SRU_PIN0

#define DAI_PB05_I_REG          SRU_PIN1
#define DAI_PB06_I_REG          SRU_PIN1
#define DAI_PB07_I_REG          SRU_PIN1
#define DAI_PB08_I_REG          SRU_PIN1

#define DAI_PB09_I_REG          SRU_PIN2
#define DAI_PB10_I_REG          SRU_PIN2
#define DAI_PB11_I_REG          SRU_PIN2
#define DAI_PB12_I_REG          SRU_PIN2

#define DAI_PB13_I_REG          SRU_PIN3
#define DAI_PB14_I_REG          SRU_PIN3
#define DAI_PB15_I_REG          SRU_PIN3
#define DAI_PB16_I_REG          SRU_PIN3

#define DAI_PB17_I_REG          SRU_PIN4
#define DAI_PB18_I_REG          SRU_PIN4
#define DAI_PB19_I_REG          SRU_PIN4
#define DAI_PB20_I_REG          SRU_PIN4


//--------------------------------------------
//  Shift Values for Bit Fields
//--------------------------------------------

// SRU_PIN0
#define DAI_PB01_I_SHIFT        0
#define DAI_PB02_I_SHIFT        7
#define DAI_PB03_I_SHIFT        14
#define DAI_PB04_I_SHIFT        21

// SRU_PIN1
#define DAI_PB05_I_SHIFT        0
#define DAI_PB06_I_SHIFT        7
#define DAI_PB07_I_SHIFT        14
#define DAI_PB08_I_SHIFT        21

// SRU_PIN2
#define DAI_PB09_I_SHIFT        0
#define DAI_PB10_I_SHIFT        7
#define DAI_PB11_I_SHIFT        14
#define DAI_PB12_I_SHIFT        21

// SRU_PIN3
#define DAI_PB13_I_SHIFT        0
#define DAI_PB14_I_SHIFT        7
#define DAI_PB15_I_SHIFT        14
#define DAI_PB16_I_SHIFT        21

//SRU_PIN4
#define DAI_PB17_I_SHIFT        0
#define DAI_PB18_I_SHIFT        7
#define DAI_PB19_I_SHIFT        14
#define DAI_PB20_I_SHIFT        21


//--------------------------------------------
//  Bit Field Codes
//--------------------------------------------
#define D_DAI_PB01_O            0x00
#define D_DAI_PB02_O            0x01
#define D_DAI_PB03_O            0x02
#define D_DAI_PB04_O            0x03
#define D_DAI_PB05_O            0x04
#define D_DAI_PB06_O            0x05
#define D_DAI_PB07_O            0x06
#define D_DAI_PB08_O            0x07
#define D_DAI_PB09_O            0x08
#define D_DAI_PB10_O            0x09
#define D_DAI_PB11_O            0x0a
#define D_DAI_PB12_O            0x0b
#define D_DAI_PB13_O            0x0c
#define D_DAI_PB14_O            0x0d
#define D_DAI_PB15_O            0x0e
#define D_DAI_PB16_O            0x0f
#define D_DAI_PB17_O            0x10
#define D_DAI_PB18_O            0x11
#define D_DAI_PB19_O            0x12
#define D_DAI_PB20_O            0x13
#define D_SPORT0_DA_O           0x14
#define D_SPORT0_DB_O           0x15
#define D_SPORT1_DA_O           0x16
#define D_SPORT1_DB_O           0x17
#define D_SPORT2_DA_O           0x18
#define D_SPORT2_DB_O           0x19
#define D_SPORT3_DA_O           0x1a
#define D_SPORT3_DB_O           0x1b
#define D_SPORT0_CLK_O          0x20
#define D_SPORT1_CLK_O          0x21
#define D_SPORT2_CLK_O          0x22
#define D_SPORT3_CLK_O          0x23
#define D_SPORT0_FS_O           0x26
#define D_SPORT1_FS_O           0x27
#define D_SPORT2_FS_O           0x28
#define D_SPORT3_FS_O           0x29
#define D_PDAP_STRB_O           0x30
#define D_PCG_CLKA_O            0x38
#define D_PCG_CLKB_O            0x39
#define D_PCG_FSA_O             0x3a
#define D_PCG_FSB_O             0x3b
#define D_DIR_DAT_O             0x41
#define D_DIR_FS_O              0x42
#define D_DIR_CLK_O             0x43
#define D_DIR_TDMCLK_O          0x44
#define D_DIT_O                 0x45
#define D_SPORT0_TDV_O          0x46
#define D_SPORT1_TDV_O          0x47
#define D_SPORT2_TDV_O          0x48
#define D_SPORT3_TDV_O          0x49
#define D_DIR_LRCLK_REF_O       0x4e
#define D_DIR_LRCLK_FB_O        0x4f
#define D_PCG_CLKC_O            0x50
#define D_PCG_CLKD_O            0x51
#define D_PCG_FSC_O             0x52
#define D_PCG_FSD_O             0x53
#define D_LOW                   0x7e
#define D_HIGH                  0x7f



//==============================================================================
//  Group E - Miscellaneous SRU Signals
//==============================================================================

//--------------------------------------------
//  Group ID Assignments
//--------------------------------------------
#define MISCA0_I_GROUP          GROUP_E
#define DAI_INT_28_I_GROUP      GROUP_E
#define MISCA1_I_GROUP          GROUP_E
#define DAI_INT_29_I_GROUP      GROUP_E
#define MISCA2_I_GROUP          GROUP_E
#define DAI_INT_30_I_GROUP      GROUP_E
#define MISCA3_I_GROUP          GROUP_E
#define DAI_INT_31_I_GROUP      GROUP_E
#define MISCA4_I_GROUP          GROUP_E
#define MISCA5_I_GROUP          GROUP_E
#define DAI_INT_22_I_GROUP      GROUP_E
#define DAI_INT_23_I_GROUP      GROUP_E
#define DAI_INT_24_I_GROUP      GROUP_E
#define DAI_INT_25_I_GROUP      GROUP_E
#define DAI_INT_26_I_GROUP      GROUP_E
#define DAI_INT_27_I_GROUP      GROUP_E

#define INV_MISCA4_I_GROUP      GROUP_G
#define INV_MISCA5_I_GROUP      GROUP_G


//--------------------------------------------
//  Register Assignments
//--------------------------------------------
#define MISCA0_I_REG            SRU_EXT_MISCA
#define DAI_INT_28_I_REG        SRU_EXT_MISCA
#define MISCA1_I_REG            SRU_EXT_MISCA
#define DAI_INT_29_I_REG        SRU_EXT_MISCA
#define MISCA2_I_REG            SRU_EXT_MISCA
#define DAI_INT_30_I_REG        SRU_EXT_MISCA
#define MISCA3_I_REG            SRU_EXT_MISCA
#define DAI_INT_31_I_REG        SRU_EXT_MISCA
#define MISCA4_I_REG            SRU_EXT_MISCA
#define MISCA5_I_REG            SRU_EXT_MISCA

#define DAI_INT_22_I_REG        SRU_EXT_MISCB
#define DAI_INT_23_I_REG        SRU_EXT_MISCB
#define DAI_INT_24_I_REG        SRU_EXT_MISCB
#define DAI_INT_25_I_REG        SRU_EXT_MISCB
#define DAI_INT_26_I_REG        SRU_EXT_MISCB
#define DAI_INT_27_I_REG        SRU_EXT_MISCB

#define INV_MISCA4_I_REG        SRU_EXT_MISCA
#define INV_MISCA5_I_REG        SRU_EXT_MISCA


//--------------------------------------------
//  Shift Values for Bit Fields
//--------------------------------------------

// SRU_EXT_MISCA
#define MISCA0_I_SHIFT          0
#define DAI_INT_28_I_SHIFT      0
#define MISCA1_I_SHIFT          5
#define DAI_INT_29_I_SHIFT      5
#define MISCA2_I_SHIFT          10
#define DAI_INT_30_I_SHIFT      10
#define MISCA3_I_SHIFT          15
#define DAI_INT_31_I_SHIFT      15
#define MISCA4_I_SHIFT          20
#define MISCA5_I_SHIFT          25


#define INV_MISCA4_I_SHIFT      30
#define INV_MISCA5_I_SHIFT      31

// SRU_EXT_MISCB
#define DAI_INT_22_I_SHIFT      0
#define DAI_INT_23_I_SHIFT      5
#define DAI_INT_24_I_SHIFT      10
#define DAI_INT_25_I_SHIFT      15
#define DAI_INT_26_I_SHIFT      20
#define DAI_INT_27_I_SHIFT      25


//--------------------------------------------
//  Bit Field Codes
//--------------------------------------------
#define E_DAI_PB01_O            0x00
#define E_DAI_PB02_O            0x01
#define E_DAI_PB03_O            0x02
#define E_DAI_PB04_O            0x03
#define E_DAI_PB05_O            0x04
#define E_DAI_PB06_O            0x05
#define E_DAI_PB07_O            0x06
#define E_DAI_PB08_O            0x07
#define E_DAI_PB09_O            0x08
#define E_DAI_PB10_O            0x09
#define E_DAI_PB11_O            0x0a
#define E_DAI_PB12_O            0x0b
#define E_DAI_PB13_O            0x0c
#define E_DAI_PB14_O            0x0d
#define E_DAI_PB15_O            0x0e
#define E_DAI_PB16_O            0x0f
#define E_DAI_PB17_O            0x10
#define E_DAI_PB18_O            0x11
#define E_DAI_PB19_O            0x12
#define E_DAI_PB20_O            0x13
#define E_SPORT0_FS_O           0x14
#define E_SPORT1_FS_O           0x15
#define E_SPORT2_FS_O           0x16
#define E_SPORT3_FS_O           0x17
#define E_PCG_CLKA_O            0x1a
#define E_PCG_FSA_O             0x1b
#define E_PCG_CLKB_O            0x1c
#define E_PCG_FSB_O             0x1d
#define E_LOW                   0x1e
#define E_HIGH                  0x1f

#define G_LOW                   0x00
#define G_HIGH                  0x01


//==============================================================================
//  Group F - Pin Buffer Enable Signals
//==============================================================================

//--------------------------------------------
//  Group ID Assignments
//--------------------------------------------

#define PBEN01_I_GROUP      GROUP_F
#define PBEN02_I_GROUP      GROUP_F
#define PBEN03_I_GROUP      GROUP_F
#define PBEN04_I_GROUP      GROUP_F
#define PBEN05_I_GROUP      GROUP_F

#define PBEN06_I_GROUP      GROUP_F
#define PBEN07_I_GROUP      GROUP_F
#define PBEN08_I_GROUP      GROUP_F
#define PBEN09_I_GROUP      GROUP_F
#define PBEN10_I_GROUP      GROUP_F

#define PBEN11_I_GROUP      GROUP_F
#define PBEN12_I_GROUP      GROUP_F
#define PBEN13_I_GROUP      GROUP_F
#define PBEN14_I_GROUP      GROUP_F
#define PBEN15_I_GROUP      GROUP_F

#define PBEN16_I_GROUP      GROUP_F
#define PBEN17_I_GROUP      GROUP_F
#define PBEN18_I_GROUP      GROUP_F
#define PBEN19_I_GROUP      GROUP_F
#define PBEN20_I_GROUP      GROUP_F

//--------------------------------------------
//  Resister Assignments
//--------------------------------------------

#define PBEN01_I_REG        SRU_PBEN0
#define PBEN02_I_REG        SRU_PBEN0
#define PBEN03_I_REG        SRU_PBEN0
#define PBEN04_I_REG        SRU_PBEN0
#define PBEN05_I_REG        SRU_PBEN0

#define PBEN06_I_REG        SRU_PBEN1
#define PBEN07_I_REG        SRU_PBEN1
#define PBEN08_I_REG        SRU_PBEN1
#define PBEN09_I_REG        SRU_PBEN1
#define PBEN10_I_REG        SRU_PBEN1

#define PBEN11_I_REG        SRU_PBEN2
#define PBEN12_I_REG        SRU_PBEN2
#define PBEN13_I_REG        SRU_PBEN2
#define PBEN14_I_REG        SRU_PBEN2
#define PBEN15_I_REG        SRU_PBEN2

#define PBEN16_I_REG        SRU_PBEN3
#define PBEN17_I_REG        SRU_PBEN3
#define PBEN18_I_REG        SRU_PBEN3
#define PBEN19_I_REG        SRU_PBEN3
#define PBEN20_I_REG        SRU_PBEN3

//--------------------------------------------
//  Shift Values for Bit Fields
//--------------------------------------------

// SRU_PBEN0
#define PBEN01_I_SHIFT      0
#define PBEN02_I_SHIFT      6
#define PBEN03_I_SHIFT      12
#define PBEN04_I_SHIFT      18
#define PBEN05_I_SHIFT      24

// SRU_PBEN1
#define PBEN06_I_SHIFT      0
#define PBEN07_I_SHIFT      6
#define PBEN08_I_SHIFT      12
#define PBEN09_I_SHIFT      18
#define PBEN10_I_SHIFT      24

// SRU_PBEN2
#define PBEN11_I_SHIFT      0
#define PBEN12_I_SHIFT      6
#define PBEN13_I_SHIFT      12
#define PBEN14_I_SHIFT      18
#define PBEN15_I_SHIFT      24

// SRU_PBEN3
#define PBEN16_I_SHIFT      0
#define PBEN17_I_SHIFT      6
#define PBEN18_I_SHIFT      12
#define PBEN19_I_SHIFT      18
#define PBEN20_I_SHIFT      24

//--------------------------------------------
//  Bit Field Codes
//--------------------------------------------
#define F_LOW                   0x00
#define F_HIGH                  0x01
#define F_MISCA0_O              0x02
#define F_MISCA1_O              0x03
#define F_MISCA2_O              0x04
#define F_MISCA3_O              0x05
#define F_MISCA4_O              0x06
#define F_MISCA5_O              0x07
#define F_SPORT0_CLK_PBEN_O     0x08
#define F_SPORT0_FS_PBEN_O      0x09
#define F_SPORT0_DA_PBEN_O      0x0a
#define F_SPORT0_DB_PBEN_O      0x0b
#define F_SPORT1_CLK_PBEN_O     0x0c
#define F_SPORT1_FS_PBEN_O      0x0d
#define F_SPORT1_DA_PBEN_O      0x0e
#define F_SPORT1_DB_PBEN_O      0x0f
#define F_SPORT2_CLK_PBEN_O     0x10
#define F_SPORT2_FS_PBEN_O      0x11
#define F_SPORT2_DA_PBEN_O      0x12
#define F_SPORT2_DB_PBEN_O      0x13
#define F_SPORT3_CLK_PBEN_O     0x14
#define F_SPORT3_FS_PBEN_O      0x15
#define F_SPORT3_DA_PBEN_O      0x16
#define F_SPORT3_DB_PBEN_O      0x17
#define F_SPORT0_TDV_PBEN_O     0x28
#define F_SPORT1_TDV_PBEN_O     0x29
#define F_SPORT2_TDV_PBEN_O     0x2a
#define F_SPORT3_TDV_PBEN_O     0x2b

//==============================================================================
//  Digital Peripheral Interface
//  Group A - Signal Assignment
//==============================================================================

// GROUP A SRU2

#define SPI_MOSI_I_GROUP        GROUP_A2
#define SPI_MISO_I_GROUP        GROUP_A2
#define SPI_DS_I_GROUP          GROUP_A2
#define SPI_CLK_I_GROUP         GROUP_A2
#define SPIB_MOSI_I_GROUP       GROUP_A2
#define SPIB_MISO_I_GROUP       GROUP_A2
#define SPIB_DS_I_GROUP         GROUP_A2
#define SPIB_CLK_I_GROUP        GROUP_A2
#define UART0_RX_I_GROUP        GROUP_A2
#define TWI_DATA_I_GROUP        GROUP_A2
#define TWI_CLK_I_GROUP         GROUP_A2
#define TIMER0_I_GROUP          GROUP_A2
#define TIMER1_I_GROUP          GROUP_A2
#define FLAG4_I_GROUP           GROUP_A2
#define FLAG5_I_GROUP           GROUP_A2
#define FLAG6_I_GROUP           GROUP_A2
#define FLAG7_I_GROUP           GROUP_A2
#define FLAG8_I_GROUP           GROUP_A2
#define FLAG9_I_GROUP           GROUP_A2
#define FLAG10_I_GROUP          GROUP_A2
#define FLAG11_I_GROUP          GROUP_A2
#define FLAG12_I_GROUP          GROUP_A2
#define FLAG13_I_GROUP          GROUP_A2
#define FLAG14_I_GROUP          GROUP_A2
#define FLAG15_I_GROUP          GROUP_A2
#define MISCB0_I_GROUP          GROUP_A2
#define MISCB1_I_GROUP          GROUP_A2
#define MISCB2_I_GROUP          GROUP_A2
#define MISCB3_I_GROUP          GROUP_A2
#define MISCB4_I_GROUP          GROUP_A2
#define MISCB5_I_GROUP          GROUP_A2
#define MISCB6_I_GROUP          GROUP_A2
#define MISCB7_I_GROUP          GROUP_A2
#define MISCB8_I_GROUP          GROUP_A2


// SRU2 REGISTER ASSIGNMENTS

#define SPI_MOSI_I_REG          SRU2_INPUT0
#define SPI_MISO_I_REG          SRU2_INPUT0
#define SPI_DS_I_REG            SRU2_INPUT0
#define SPI_CLK_I_REG           SRU2_INPUT0
#define SPIB_MOSI_I_REG         SRU2_INPUT0
#define SPIB_MISO_I_REG         SRU2_INPUT0

#define SPIB_DS_I_REG           SRU2_INPUT1
#define SPIB_CLK_I_REG          SRU2_INPUT1
#define UART0_RX_I_REG          SRU2_INPUT1
#define TWI_DATA_I_REG          SRU2_INPUT1
#define TWI_CLK_I_REG           SRU2_INPUT1

#define TIMER0_I_REG            SRU2_INPUT2
#define TIMER1_I_REG            SRU2_INPUT2
#define FLAG4_I_REG             SRU2_INPUT2
#define FLAG5_I_REG             SRU2_INPUT2
#define FLAG6_I_REG             SRU2_INPUT2

#define FLAG7_I_REG             SRU2_INPUT3
#define FLAG8_I_REG             SRU2_INPUT3
#define FLAG9_I_REG             SRU2_INPUT3
#define FLAG10_I_REG            SRU2_INPUT3
#define FLAG11_I_REG            SRU2_INPUT3
#define FLAG12_I_REG            SRU2_INPUT3

#define FLAG13_I_REG            SRU2_INPUT4
#define FLAG14_I_REG            SRU2_INPUT4
#define FLAG15_I_REG            SRU2_INPUT4
#define MISCB0_I_REG            SRU2_INPUT4
#define MISCB1_I_REG            SRU2_INPUT4
#define MISCB2_I_REG            SRU2_INPUT4

#define MISCB3_I_REG            SRU2_INPUT5
#define MISCB4_I_REG            SRU2_INPUT5
#define MISCB5_I_REG            SRU2_INPUT5
#define MISCB6_I_REG            SRU2_INPUT5
#define MISCB7_I_REG            SRU2_INPUT5
#define MISCB8_I_REG            SRU2_INPUT5

//SRU2 SHIFT VALUES FOR BIT FIELDS

//SRU2_INPUT0
#define SPI_MOSI_I_SHIFT        0
#define SPI_MISO_I_SHIFT        5
#define SPI_DS_I_SHIFT          10
#define SPI_CLK_I_SHIFT         15
#define SPIB_MOSI_I_SHIFT       20
#define SPIB_MISO_I_SHIFT       25

//SRU2_INPUT1
#define SPIB_DS_I_SHIFT         0
#define SPIB_CLK_I_SHIFT        5
#define UART0_RX_I_SHIFT        10
#define TWI_DATA_I_SHIFT        20
#define TWI_CLK_I_SHIFT         25

//SRU2_INPUT2
#define TIMER0_I_SHIFT          0
#define TIMER1_I_SHIFT          5
#define FLAG4_I_SHIFT           15
#define FLAG5_I_SHIFT           20
#define FLAG6_I_SHIFT           25

//SRU2_INPUT3
#define FLAG7_I_SHIFT           0
#define FLAG8_I_SHIFT           5
#define FLAG9_I_SHIFT           10
#define FLAG10_I_SHIFT          15
#define FLAG11_I_SHIFT          20
#define FLAG12_I_SHIFT          25

//SRU2_INPUT4
#define FLAG13_I_SHIFT          0
#define FLAG14_I_SHIFT          5
#define FLAG15_I_SHIFT          10
#define MISCB0_I_SHIFT          15
#define MISCB1_I_SHIFT          20
#define MISCB2_I_SHIFT          25

//SRU2_INPUT5
#define MISCB3_I_SHIFT          0
#define MISCB4_I_SHIFT          5
#define MISCB5_I_SHIFT          10
#define MISCB6_I_SHIFT          15
#define MISCB7_I_SHIFT          20
#define MISCB8_I_SHIFT          25

//Bit Field Codes For SRU2

#define A2_LOW                  0x00
#define A2_HIGH                 0x01
#define A2_DPI_PB01_O           0x02
#define A2_DPI_PB02_O           0x03
#define A2_DPI_PB03_O           0x04
#define A2_DPI_PB04_O           0x05
#define A2_DPI_PB05_O           0x06
#define A2_DPI_PB06_O           0x07
#define A2_DPI_PB07_O           0x08
#define A2_DPI_PB08_O           0x09
#define A2_DPI_PB09_O           0x0a
#define A2_DPI_PB10_O           0x0b
#define A2_DPI_PB11_O           0x0c
#define A2_DPI_PB12_O           0x0d
#define A2_DPI_PB13_O           0x0e
#define A2_DPI_PB14_O           0x0f
#define A2_TIMER0_O             0x10
#define A2_TIMER1_O             0x11
#define A2_UART0_TX_O           0x13

//==============================================================================
//  Digital Peripheral Interface
//  Group B - Pin Assignment
//==============================================================================

// GROUP B SRU2

#define DPI_PB01_I_GROUP        GROUP_B2
#define DPI_PB02_I_GROUP        GROUP_B2
#define DPI_PB03_I_GROUP        GROUP_B2
#define DPI_PB04_I_GROUP        GROUP_B2
#define DPI_PB05_I_GROUP        GROUP_B2
#define DPI_PB06_I_GROUP        GROUP_B2
#define DPI_PB07_I_GROUP        GROUP_B2
#define DPI_PB08_I_GROUP        GROUP_B2
#define DPI_PB09_I_GROUP        GROUP_B2
#define DPI_PB10_I_GROUP        GROUP_B2
#define DPI_PB11_I_GROUP        GROUP_B2
#define DPI_PB12_I_GROUP        GROUP_B2
#define DPI_PB13_I_GROUP        GROUP_B2
#define DPI_PB14_I_GROUP        GROUP_B2

// SRU2 REGISTER ASSIGNMENTS

#define DPI_PB01_I_REG          SRU2_PIN0
#define DPI_PB02_I_REG          SRU2_PIN0
#define DPI_PB03_I_REG          SRU2_PIN0
#define DPI_PB04_I_REG          SRU2_PIN0
#define DPI_PB05_I_REG          SRU2_PIN0

#define DPI_PB06_I_REG          SRU2_PIN1
#define DPI_PB07_I_REG          SRU2_PIN1
#define DPI_PB08_I_REG          SRU2_PIN1
#define DPI_PB09_I_REG          SRU2_PIN1
#define DPI_PB10_I_REG          SRU2_PIN1

#define DPI_PB11_I_REG          SRU2_PIN2
#define DPI_PB12_I_REG          SRU2_PIN2
#define DPI_PB13_I_REG          SRU2_PIN2
#define DPI_PB14_I_REG          SRU2_PIN2

// SRU2 Shift Values for Bit Fields

// SRU2_PIN0
#define DPI_PB01_I_SHIFT        0
#define DPI_PB02_I_SHIFT        6
#define DPI_PB03_I_SHIFT        12
#define DPI_PB04_I_SHIFT        18
#define DPI_PB05_I_SHIFT        24

//SRU2_PIN1
#define DPI_PB06_I_SHIFT        0
#define DPI_PB07_I_SHIFT        6
#define DPI_PB08_I_SHIFT        12
#define DPI_PB09_I_SHIFT        18
#define DPI_PB10_I_SHIFT        24

//SRU2_PIN2
#define DPI_PB11_I_SHIFT        0
#define DPI_PB12_I_SHIFT        6
#define DPI_PB13_I_SHIFT        12
#define DPI_PB14_I_SHIFT        18

//SRU2 Bit Fields
#define B2_LOW                  0x00
#define B2_HIGH                 0x01
#define B2_DPI_PB01_O           0x02
#define B2_DPI_PB02_O           0x03
#define B2_DPI_PB03_O           0x04
#define B2_DPI_PB04_O           0x05
#define B2_DPI_PB05_O           0x06
#define B2_DPI_PB06_O           0x07
#define B2_DPI_PB07_O           0x08
#define B2_DPI_PB08_O           0x09
#define B2_DPI_PB09_O           0x0a
#define B2_DPI_PB10_O           0x0b
#define B2_DPI_PB11_O           0x0c
#define B2_DPI_PB12_O           0x0d
#define B2_DPI_PB13_O           0x0e
#define B2_DPI_PB14_O           0x0f
#define B2_TIMER0_O             0x10
#define B2_TIMER1_O             0x11
#define B2_UART0_TX_O           0x13
#define B2_SPI_MISO_O           0x15
#define B2_SPI_MOSI_O           0x16
#define B2_SPI_CLK_O            0x17
#define B2_SPI_FLG0_O           0x18
#define B2_SPI_FLG1_O           0x19
#define B2_SPI_FLG2_O           0x1a
#define B2_SPI_FLG3_O           0x1b
#define B2_SPIB_MISO_O          0x1c
#define B2_SPIB_MOSI_O          0x1d
#define B2_SPIB_CLK_O           0x1e
#define B2_SPIB_FLG0_O          0x1f
#define B2_SPIB_FLG1_O          0x20
#define B2_SPIB_FLG2_O          0x21
#define B2_SPIB_FLG3_O          0x22
#define B2_FLAG4_O              0x23
#define B2_FLAG5_O              0x24
#define B2_FLAG6_O              0x25
#define B2_FLAG7_O              0x26
#define B2_FLAG8_O              0x27
#define B2_FLAG9_O              0x28
#define B2_FLAG10_O             0x29
#define B2_FLAG11_O             0x2a
#define B2_FLAG12_O             0x2b
#define B2_FLAG13_O             0x2c
#define B2_FLAG14_O             0x2d
#define B2_FLAG15_O             0x2e
#define B2_PCG_CLKC_O           0x2f
#define B2_PCG_CLKD_O           0x30
#define B2_PCG_FSC_O            0x31
#define B2_PCG_FSD_O            0x32

//==============================================================================
//  Digital Peripheral Interface
//  Group B - Pin Enables
//==============================================================================
// SRU2 GROUP C2
#define DPI_PBEN01_I_GROUP      GROUP_C2
#define DPI_PBEN02_I_GROUP      GROUP_C2
#define DPI_PBEN03_I_GROUP      GROUP_C2
#define DPI_PBEN04_I_GROUP      GROUP_C2
#define DPI_PBEN05_I_GROUP      GROUP_C2
#define DPI_PBEN06_I_GROUP      GROUP_C2
#define DPI_PBEN07_I_GROUP      GROUP_C2
#define DPI_PBEN08_I_GROUP      GROUP_C2
#define DPI_PBEN09_I_GROUP      GROUP_C2
#define DPI_PBEN10_I_GROUP      GROUP_C2
#define DPI_PBEN11_I_GROUP      GROUP_C2
#define DPI_PBEN12_I_GROUP      GROUP_C2
#define DPI_PBEN13_I_GROUP      GROUP_C2
#define DPI_PBEN14_I_GROUP      GROUP_C2

//SRU2 Register Assignments

#define DPI_PBEN01_I_REG      SRU2_PBEN0
#define DPI_PBEN02_I_REG      SRU2_PBEN0
#define DPI_PBEN03_I_REG      SRU2_PBEN0
#define DPI_PBEN04_I_REG      SRU2_PBEN0
#define DPI_PBEN05_I_REG      SRU2_PBEN0

#define DPI_PBEN06_I_REG      SRU2_PBEN1
#define DPI_PBEN07_I_REG      SRU2_PBEN1
#define DPI_PBEN08_I_REG      SRU2_PBEN1
#define DPI_PBEN09_I_REG      SRU2_PBEN1
#define DPI_PBEN10_I_REG      SRU2_PBEN1

#define DPI_PBEN11_I_REG      SRU2_PBEN2
#define DPI_PBEN12_I_REG      SRU2_PBEN2
#define DPI_PBEN13_I_REG      SRU2_PBEN2
#define DPI_PBEN14_I_REG      SRU2_PBEN2

//SRU2 Shift Values for Bit Fields

// SRU2_PBEN0
#define DPI_PBEN01_I_SHIFT      0
#define DPI_PBEN02_I_SHIFT      6
#define DPI_PBEN03_I_SHIFT      12
#define DPI_PBEN04_I_SHIFT      18
#define DPI_PBEN05_I_SHIFT      24

// SRU2_PBEN1
#define DPI_PBEN06_I_SHIFT      0
#define DPI_PBEN07_I_SHIFT      6
#define DPI_PBEN08_I_SHIFT      12
#define DPI_PBEN09_I_SHIFT      18
#define DPI_PBEN10_I_SHIFT      24

// SRU2_PBEN2
#define DPI_PBEN11_I_SHIFT      0
#define DPI_PBEN12_I_SHIFT      6
#define DPI_PBEN13_I_SHIFT      12
#define DPI_PBEN14_I_SHIFT      18

//SRU2 Bit Field Codes

#define C2_LOW                  0x00
#define C2_HIGH                 0x01
#define C2_MISC0_O              0x02
#define C2_MISC1_O              0x03
#define C2_MISC2_O              0x04
#define C2_TIMER0_PBEN_O        0x05
#define C2_TIMER1_PBEN_O        0x06
#define C2_UART0_TX_PBEN_O      0x08
#define C2_SPI_MISO_PBEN_O      0x0a
#define C2_SPI_MOSI_PBEN_O      0x0b
#define C2_SPI_CLK_PBEN_O       0x0c
#define C2_SPI_FLG0_PBEN_O      0x0d
#define C2_SPI_FLG1_PBEN_O      0x0e
#define C2_SPI_FLG2_PBEN_O      0x0f
#define C2_SPI_FLG3_PBEN_O      0x10
#define C2_SPIB_MISO_PBEN_O     0x11
#define C2_SPIB_MOSI_PBEN_O     0x12
#define C2_SPIB_CLK_PBEN_O      0x13
#define C2_SPIB_FLG0_PBEN_O     0x14
#define C2_SPIB_FLG1_PBEN_O     0x15
#define C2_SPIB_FLG2_PBEN_O     0x16
#define C2_SPIB_FLG3_PBEN_O     0x17
#define C2_FLAG4_PBEN_O         0x18
#define C2_FLAG5_PBEN_O         0x19
#define C2_FLAG6_PBEN_O         0x1a
#define C2_FLAG7_PBEN_O         0x1b
#define C2_FLAG8_PBEN_O         0x1c
#define C2_FLAG9_PBEN_O         0x1d
#define C2_FLAG10_PBEN_O        0x1e
#define C2_FLAG11_PBEN_O        0x1f
#define C2_FLAG12_PBEN_O        0x20
#define C2_FLAG13_PBEN_O        0x21
#define C2_FLAG14_PBEN_O        0x22
#define C2_FLAG15_PBEN_O        0x23
#define C2_TWI_DATA_PBEN_O      0x24
#define C2_TWI_CLK_PBEN_O       0x25
#define C2_MISC3_O              0x26
#define C2_MISC4_O              0x27
#define C2_MISC5_O              0x28
#define C2_MISC6_O              0x29
#define C2_MISC7_O              0x2a
#define C2_MISC8_O              0x2b


//==============================================================================
//  Dummy Signals
//  The signals listed below don't exist in the given group but they are
//  required by the preprocessor for evaluating the macros sru_fiels and
//  sru_mask. The code assigned to them them ara arbitrary.
//==============================================================================

// Group A dummy signals
#define A_SPORT0_DA_O           0xFFFFFFFF
#define A_SPORT0_DB_O           0xFFFFFFFF
#define A_SPORT1_DA_O           0xFFFFFFFF
#define A_SPORT1_DB_O           0xFFFFFFFF
#define A_SPORT2_DA_O           0xFFFFFFFF
#define A_SPORT2_DB_O           0xFFFFFFFF
#define A_SPORT3_DA_O           0xFFFFFFFF
#define A_SPORT3_DB_O           0xFFFFFFFF
#define A_SPORT0_FS_O           0xFFFFFFFF
#define A_SPORT1_FS_O           0xFFFFFFFF
#define A_SPORT2_FS_O           0xFFFFFFFF
#define A_SPORT3_FS_O           0xFFFFFFFF
#define A_PCG_FSA_O             0xFFFFFFFF
#define A_PCG_FSB_O             0xFFFFFFFF

#define A_SPORT0_DA_O           0xFFFFFFFF
#define A_SPORT0_DB_O           0xFFFFFFFF
#define A_SPORT1_DA_O           0xFFFFFFFF
#define A_SPORT1_DB_O           0xFFFFFFFF
#define A_SPORT2_DA_O           0xFFFFFFFF
#define A_SPORT2_DB_O           0xFFFFFFFF
#define A_SPORT3_DA_O           0xFFFFFFFF
#define A_SPORT3_DB_O           0xFFFFFFFF
#define A_SPORT0_FS_O           0xFFFFFFFF
#define A_SPORT1_FS_O           0xFFFFFFFF
#define A_SPORT2_FS_O           0xFFFFFFFF
#define A_SPORT3_FS_O           0xFFFFFFFF
#define A_TIMER0_O              0xFFFFFFFF
#define A_TIMER1_O              0xFFFFFFFF
#define A_FLAG10_O              0xFFFFFFFF
#define A_MISCB_2_O             0xFFFFFFFF
#define A_MISCB_3_O             0xFFFFFFFF
#define A_MISCB_4_O             0xFFFFFFFF
#define A_MISCB_5_O             0xFFFFFFFF
#define A_FLAG11_O              0xFFFFFFFF
#define A_FLAG12_O              0xFFFFFFFF
#define A_FLAG13_O              0xFFFFFFFF
#define A_FLAG14_O              0xFFFFFFFF
#define A_PCG_FSA_O             0xFFFFFFFF
#define A_PCG_FSB_O             0xFFFFFFFF
#define A_FLAG15_O              0xFFFFFFFF

#define A_TIMER0_O              0xFFFFFFFF
#define A_TIMER1_O              0xFFFFFFFF
#define A_PDAP_STRB_O           0xFFFFFFFF
#define A_PCG_FSA_O             0xFFFFFFFF
#define A_PCG_FSB_O             0xFFFFFFFF

#define A_MISCA0_O              0xFFFFFFFF
#define A_MISCA1_O              0xFFFFFFFF
#define A_MISCA2_O              0xFFFFFFFF
#define A_MISCA3_O              0xFFFFFFFF
#define A_MISCA4_O              0xFFFFFFFF
#define A_MISCA5_O              0xFFFFFFFF
#define A_SPORT0_CLK_PBEN_O     0xFFFFFFFF
#define A_SPORT0_FS_PBEN_O      0xFFFFFFFF
#define A_SPORT0_DA_PBEN_O      0xFFFFFFFF
#define A_SPORT0_DB_PBEN_O      0xFFFFFFFF
#define A_SPORT1_CLK_PBEN_O     0xFFFFFFFF
#define A_SPORT1_FS_PBEN_O      0xFFFFFFFF
#define A_SPORT1_DA_PBEN_O      0xFFFFFFFF
#define A_SPORT1_DB_PBEN_O      0xFFFFFFFF
#define A_SPORT2_CLK_PBEN_O     0xFFFFFFFF
#define A_SPORT2_FS_PBEN_O      0xFFFFFFFF
#define A_SPORT2_DA_PBEN_O      0xFFFFFFFF
#define A_SPORT2_DB_PBEN_O      0xFFFFFFFF
#define A_SPORT3_CLK_PBEN_O     0xFFFFFFFF
#define A_SPORT3_FS_PBEN_O      0xFFFFFFFF
#define A_SPORT3_DA_PBEN_O      0xFFFFFFFF
#define A_SPORT3_DB_PBEN_O      0xFFFFFFFF
#define A_TIMER0_PBEN_O         0xFFFFFFFF
#define A_TIMER1_PBEN_O         0xFFFFFFFF
#define A_FLAG10_PBEN_O         0xFFFFFFFF
#define A_FLAG11_PBEN_O         0xFFFFFFFF
#define A_FLAG12_PBEN_O         0xFFFFFFFF
#define A_FLAG13_PBEN_O         0xFFFFFFFF
#define A_FLAG14_PBEN_O         0xFFFFFFFF
#define A_FLAG15_PBEN_O         0xFFFFFFFF


#define A_DIR_DAT_O             0xFFFFFFFF
#define A_DIR_FS_O              0xFFFFFFFF
#define A_DIT_O                 0xFFFFFFFF
#define A_SPIB_MISO_O           0xFFFFFFFF
#define A_SPIB_MOSI_O           0xFFFFFFFF
#define A_SPIB_CLK_O            0xFFFFFFFF
#define A_SPIB_FLG0_O           0xFFFFFFFF
#define A_SPIB_FLG1_O           0xFFFFFFFF
#define A_SPIB_FLG2_O           0xFFFFFFFF
#define A_SPIB_FLG3_O           0xFFFFFFFF
#define A_DIR_LRCLK_FB_O        0xFFFFFFFF
#define A_DIR_LRCLK_REF_O       0xFFFFFFFF
#define A_SPORT0_TDV_O          0xFFFFFFFF
#define A_SPORT1_TDV_O          0xFFFFFFFF
#define A_SPORT2_TDV_O          0xFFFFFFFF
#define A_SPORT3_TDV_O          0xFFFFFFFF
#define A_PCG_CLKC_O            0xFFFFFFFF
#define A_PCG_CLKD_O            0xFFFFFFFF
#define A_PCG_FSC_O             0xFFFFFFFF
#define A_PCG_FSD_O             0xFFFFFFFF
#define A_SPORT0_TDV_PBEN_O     0xFFFFFFFF
#define A_SPORT1_TDV_PBEN_O     0xFFFFFFFF
#define A_SPORT2_TDV_PBEN_O     0xFFFFFFFF
#define A_SPORT3_TDV_PBEN_O     0xFFFFFFFF
#define A_DPI_PB01_O            0xFFFFFFFF
#define A_DPI_PB02_O            0xFFFFFFFF
#define A_DPI_PB03_O            0xFFFFFFFF
#define A_DPI_PB04_O            0xFFFFFFFF
#define A_DPI_PB05_O            0xFFFFFFFF
#define A_DPI_PB06_O            0xFFFFFFFF
#define A_DPI_PB07_O            0xFFFFFFFF
#define A_DPI_PB08_O            0xFFFFFFFF
#define A_DPI_PB09_O            0xFFFFFFFF
#define A_DPI_PB10_O            0xFFFFFFFF
#define A_DPI_PB11_O            0xFFFFFFFF
#define A_DPI_PB12_O            0xFFFFFFFF
#define A_DPI_PB13_O            0xFFFFFFFF
#define A_DPI_PB14_O            0xFFFFFFFF
#define A_UART0_TX_O            0xFFFFFFFF
#define A_SPI_MISO_O            0xFFFFFFFF
#define A_SPI_MOSI_O            0xFFFFFFFF
#define A_SPI_CLK_O             0xFFFFFFFF
#define A_SPI_FLG0_O            0xFFFFFFFF
#define A_SPI_FLG1_O            0xFFFFFFFF
#define A_SPI_FLG2_O            0xFFFFFFFF
#define A_SPI_FLG3_O            0xFFFFFFFF
#define A_FLAG4_O               0xFFFFFFFF
#define A_FLAG5_O               0xFFFFFFFF
#define A_FLAG6_O               0xFFFFFFFF
#define A_FLAG7_O               0xFFFFFFFF
#define A_FLAG8_O               0xFFFFFFFF
#define A_FLAG9_O               0xFFFFFFFF
#define A_FLAG10_O              0xFFFFFFFF
#define A_FLAG11_O              0xFFFFFFFF
#define A_FLAG12_O              0xFFFFFFFF
#define A_FLAG13_O              0xFFFFFFFF
#define A_FLAG14_O              0xFFFFFFFF
#define A_FLAG15_O              0xFFFFFFFF
#define A_MISC0_O               0xFFFFFFFF
#define A_MISC1_O               0xFFFFFFFF
#define A_MISC2_O               0xFFFFFFFF
#define A_UART0_TX_PBEN_O       0xFFFFFFFF
#define A_SPI_MISO_PBEN_O       0xFFFFFFFF
#define A_SPI_MOSI_PBEN_O       0xFFFFFFFF
#define A_SPI_CLK_PBEN_O        0xFFFFFFFF
#define A_SPI_FLG0_PBEN_O       0xFFFFFFFF
#define A_SPI_FLG1_PBEN_O       0xFFFFFFFF
#define A_SPI_FLG2_PBEN_O       0xFFFFFFFF
#define A_SPI_FLG3_PBEN_O       0xFFFFFFFF
#define A_SPIB_MISO_PBEN_O      0xFFFFFFFF
#define A_SPIB_MOSI_PBEN_O      0xFFFFFFFF
#define A_SPIB_CLK_PBEN_O       0xFFFFFFFF
#define A_SPIB_FLG0_PBEN_O      0xFFFFFFFF
#define A_SPIB_FLG1_PBEN_O      0xFFFFFFFF
#define A_SPIB_FLG2_PBEN_O      0xFFFFFFFF
#define A_SPIB_FLG3_PBEN_O      0xFFFFFFFF
#define A_FLAG4_PBEN_O          0xFFFFFFFF
#define A_FLAG5_PBEN_O          0xFFFFFFFF
#define A_FLAG6_PBEN_O          0xFFFFFFFF
#define A_FLAG7_PBEN_O          0xFFFFFFFF
#define A_FLAG8_PBEN_O          0xFFFFFFFF
#define A_FLAG9_PBEN_O          0xFFFFFFFF
#define A_FLAG10_PBEN_O         0xFFFFFFFF
#define A_FLAG11_PBEN_O         0xFFFFFFFF
#define A_FLAG12_PBEN_O         0xFFFFFFFF
#define A_FLAG13_PBEN_O         0xFFFFFFFF
#define A_FLAG14_PBEN_O         0xFFFFFFFF
#define A_FLAG15_PBEN_O         0xFFFFFFFF
#define A_TWI_DATA_PBEN_O       0xFFFFFFFF
#define A_TWI_CLK_PBEN_O        0xFFFFFFFF
#define A_MISC3_O               0xFFFFFFFF
#define A_MISC4_O               0xFFFFFFFF
#define A_MISC5_O               0xFFFFFFFF
#define A_MISC6_O               0xFFFFFFFF
#define A_MISC7_O               0xFFFFFFFF
#define A_MISC8_O               0xFFFFFFFF




// Group B dummy signals
#define B_SPORT0_CLK_O          0xFFFFFFFF
#define B_SPORT1_CLK_O          0xFFFFFFFF
#define B_SPORT2_CLK_O          0xFFFFFFFF
#define B_SPORT3_CLK_O          0xFFFFFFFF
#define B_PCG_CLKA_O            0xFFFFFFFF
#define B_PCG_CLKB_O            0xFFFFFFFF

#define B_SPORT0_FS_O           0xFFFFFFFF
#define B_SPORT1_FS_O           0xFFFFFFFF
#define B_SPORT2_FS_O           0xFFFFFFFF
#define B_SPORT3_FS_O           0xFFFFFFFF
#define B_PCG_FSA_O             0xFFFFFFFF
#define B_PCG_FSB_O             0xFFFFFFFF

#define B_SPORT0_CLK_O          0xFFFFFFFF
#define B_SPORT1_CLK_O          0xFFFFFFFF
#define B_SPORT2_CLK_O          0xFFFFFFFF
#define B_SPORT3_CLK_O          0xFFFFFFFF
#define B_SPORT0_FS_O           0xFFFFFFFF
#define B_SPORT1_FS_O           0xFFFFFFFF
#define B_SPORT2_FS_O           0xFFFFFFFF
#define B_SPORT3_FS_O           0xFFFFFFFF
#define B_TIMER0_O              0xFFFFFFFF
#define B_TIMER1_O              0xFFFFFFFF
#define B_FLAG10_O              0xFFFFFFFF
#define B_MISCB_2_O             0xFFFFFFFF
#define B_MISCB_3_O             0xFFFFFFFF
#define B_MISCB_4_O             0xFFFFFFFF
#define B_MISCB_5_O             0xFFFFFFFF
#define B_FLAG11_O              0xFFFFFFFF
#define B_FLAG12_O              0xFFFFFFFF
#define B_FLAG13_O              0xFFFFFFFF
#define B_FLAG14_O              0xFFFFFFFF
#define B_PCG_CLKA_O            0xFFFFFFFF
#define B_PCG_CLKB_O            0xFFFFFFFF
#define B_PCG_FSA_O             0xFFFFFFFF
#define B_PCG_FSB_O             0xFFFFFFFF
#define B_FLAG15_O              0xFFFFFFFF

#define B_TIMER0_O              0xFFFFFFFF
#define B_TIMER1_O              0xFFFFFFFF
#define B_PDAP_STRB_O           0xFFFFFFFF
#define B_PCG_CLKA_O            0xFFFFFFFF
#define B_PCG_FSA_O             0xFFFFFFFF
#define B_PCG_CLKB_O            0xFFFFFFFF
#define B_PCG_FSB_O             0xFFFFFFFF

#define B_MISCA0_O              0xFFFFFFFF
#define B_MISCA1_O              0xFFFFFFFF
#define B_MISCA2_O              0xFFFFFFFF
#define B_MISCA3_O              0xFFFFFFFF
#define B_MISCA4_O              0xFFFFFFFF
#define B_MISCA5_O              0xFFFFFFFF
#define B_SPORT0_CLK_PBEN_O     0xFFFFFFFF
#define B_SPORT0_FS_PBEN_O      0xFFFFFFFF
#define B_SPORT0_DA_PBEN_O      0xFFFFFFFF
#define B_SPORT0_DB_PBEN_O      0xFFFFFFFF
#define B_SPORT1_CLK_PBEN_O     0xFFFFFFFF
#define B_SPORT1_FS_PBEN_O      0xFFFFFFFF
#define B_SPORT1_DA_PBEN_O      0xFFFFFFFF
#define B_SPORT1_DB_PBEN_O      0xFFFFFFFF
#define B_SPORT2_CLK_PBEN_O     0xFFFFFFFF
#define B_SPORT2_FS_PBEN_O      0xFFFFFFFF
#define B_SPORT2_DA_PBEN_O      0xFFFFFFFF
#define B_SPORT2_DB_PBEN_O      0xFFFFFFFF
#define B_SPORT3_CLK_PBEN_O     0xFFFFFFFF
#define B_SPORT3_FS_PBEN_O      0xFFFFFFFF
#define B_SPORT3_DA_PBEN_O      0xFFFFFFFF
#define B_SPORT3_DB_PBEN_O      0xFFFFFFFF
#define B_TIMER0_PBEN_O         0xFFFFFFFF
#define B_TIMER1_PBEN_O         0xFFFFFFFF
#define B_FLAG10_PBEN_O         0xFFFFFFFF
#define B_FLAG11_PBEN_O         0xFFFFFFFF
#define B_FLAG12_PBEN_O         0xFFFFFFFF
#define B_FLAG13_PBEN_O         0xFFFFFFFF
#define B_FLAG14_PBEN_O         0xFFFFFFFF
#define B_FLAG15_PBEN_O         0xFFFFFFFF

#define B_DIR_CLK_O             0xFFFFFFFF
#define B_DIR_TDMCLK_O          0xFFFFFFFF
#define B_DIR_FS_O              0xFFFFFFFF
#define B_SPIB_MISO_O           0xFFFFFFFF
#define B_SPIB_MOSI_O           0xFFFFFFFF
#define B_SPIB_CLK_O            0xFFFFFFFF
#define B_SPIB_FLG0_O           0xFFFFFFFF
#define B_SPIB_FLG1_O           0xFFFFFFFF
#define B_SPIB_FLG2_O           0xFFFFFFFF
#define B_SPIB_FLG3_O           0xFFFFFFFF
#define B_DIR_LRCLK_FB_O        0xFFFFFFFF
#define B_DIR_LRCLK_REF_O       0xFFFFFFFF
#define B_SPORT0_TDV_O          0xFFFFFFFF
#define B_SPORT1_TDV_O          0xFFFFFFFF
#define B_SPORT2_TDV_O          0xFFFFFFFF
#define B_SPORT3_TDV_O          0xFFFFFFFF
#define B_PCG_CLKC_O            0xFFFFFFFF
#define B_PCG_CLKD_O            0xFFFFFFFF
#define B_PCG_FSC_O             0xFFFFFFFF
#define B_PCG_FSD_O             0xFFFFFFFF
#define B_SPORT0_TDV_PBEN_O     0xFFFFFFFF
#define B_SPORT1_TDV_PBEN_O     0xFFFFFFFF
#define B_SPORT2_TDV_PBEN_O     0xFFFFFFFF
#define B_SPORT3_TDV_PBEN_O     0xFFFFFFFF
#define B_DPI_PB01_O            0xFFFFFFFF
#define B_DPI_PB02_O            0xFFFFFFFF
#define B_DPI_PB03_O            0xFFFFFFFF
#define B_DPI_PB04_O            0xFFFFFFFF
#define B_DPI_PB05_O            0xFFFFFFFF
#define B_DPI_PB06_O            0xFFFFFFFF
#define B_DPI_PB07_O            0xFFFFFFFF
#define B_DPI_PB08_O            0xFFFFFFFF
#define B_DPI_PB09_O            0xFFFFFFFF
#define B_DPI_PB10_O            0xFFFFFFFF
#define B_DPI_PB11_O            0xFFFFFFFF
#define B_DPI_PB12_O            0xFFFFFFFF
#define B_DPI_PB13_O            0xFFFFFFFF
#define B_DPI_PB14_O            0xFFFFFFFF
#define B_UART0_TX_O            0xFFFFFFFF
#define B_SPI_MISO_O            0xFFFFFFFF
#define B_SPI_MOSI_O            0xFFFFFFFF
#define B_SPI_CLK_O             0xFFFFFFFF
#define B_SPI_FLG0_O            0xFFFFFFFF
#define B_SPI_FLG1_O            0xFFFFFFFF
#define B_SPI_FLG2_O            0xFFFFFFFF
#define B_SPI_FLG3_O            0xFFFFFFFF
#define B_FLAG4_O               0xFFFFFFFF
#define B_FLAG5_O               0xFFFFFFFF
#define B_FLAG6_O               0xFFFFFFFF
#define B_FLAG7_O               0xFFFFFFFF
#define B_FLAG8_O               0xFFFFFFFF
#define B_FLAG9_O               0xFFFFFFFF
#define B_FLAG10_O              0xFFFFFFFF
#define B_FLAG11_O              0xFFFFFFFF
#define B_FLAG12_O              0xFFFFFFFF
#define B_FLAG13_O              0xFFFFFFFF
#define B_FLAG14_O              0xFFFFFFFF
#define B_FLAG15_O              0xFFFFFFFF
#define B_MISC0_O               0xFFFFFFFF
#define B_MISC1_O               0xFFFFFFFF
#define B_MISC2_O               0xFFFFFFFF
#define B_UART0_TX_PBEN_O       0xFFFFFFFF
#define B_SPI_MISO_PBEN_O       0xFFFFFFFF
#define B_SPI_MOSI_PBEN_O       0xFFFFFFFF
#define B_SPI_CLK_PBEN_O        0xFFFFFFFF
#define B_SPI_FLG0_PBEN_O       0xFFFFFFFF
#define B_SPI_FLG1_PBEN_O       0xFFFFFFFF
#define B_SPI_FLG2_PBEN_O       0xFFFFFFFF
#define B_SPI_FLG3_PBEN_O       0xFFFFFFFF
#define B_SPIB_MISO_PBEN_O      0xFFFFFFFF
#define B_SPIB_MOSI_PBEN_O      0xFFFFFFFF
#define B_SPIB_CLK_PBEN_O       0xFFFFFFFF
#define B_SPIB_FLG0_PBEN_O      0xFFFFFFFF
#define B_SPIB_FLG1_PBEN_O      0xFFFFFFFF
#define B_SPIB_FLG2_PBEN_O      0xFFFFFFFF
#define B_SPIB_FLG3_PBEN_O      0xFFFFFFFF
#define B_FLAG4_PBEN_O          0xFFFFFFFF
#define B_FLAG5_PBEN_O          0xFFFFFFFF
#define B_FLAG6_PBEN_O          0xFFFFFFFF
#define B_FLAG7_PBEN_O          0xFFFFFFFF
#define B_FLAG8_PBEN_O          0xFFFFFFFF
#define B_FLAG9_PBEN_O          0xFFFFFFFF
#define B_FLAG10_PBEN_O         0xFFFFFFFF
#define B_FLAG11_PBEN_O         0xFFFFFFFF
#define B_FLAG12_PBEN_O         0xFFFFFFFF
#define B_FLAG13_PBEN_O         0xFFFFFFFF
#define B_FLAG14_PBEN_O         0xFFFFFFFF
#define B_FLAG15_PBEN_O         0xFFFFFFFF
#define B_TWI_DATA_PBEN_O       0xFFFFFFFF
#define B_TWI_CLK_PBEN_O        0xFFFFFFFF
#define B_MISC3_O               0xFFFFFFFF
#define B_MISC4_O               0xFFFFFFFF
#define B_MISC5_O               0xFFFFFFFF
#define B_MISC6_O               0xFFFFFFFF
#define B_MISC7_O               0xFFFFFFFF
#define B_MISC8_O               0xFFFFFFFF



// Group C dummy signals
#define C_SPORT0_CLK_O          0xFFFFFFFF
#define C_SPORT1_CLK_O          0xFFFFFFFF
#define C_SPORT2_CLK_O          0xFFFFFFFF
#define C_SPORT3_CLK_O          0xFFFFFFFF
#define C_PCG_CLKA_O            0xFFFFFFFF
#define C_PCG_CLKB_O            0xFFFFFFFF

#define C_SPORT0_DA_O           0xFFFFFFFF
#define C_SPORT0_DB_O           0xFFFFFFFF
#define C_SPORT1_DA_O           0xFFFFFFFF
#define C_SPORT1_DB_O           0xFFFFFFFF
#define C_SPORT2_DA_O           0xFFFFFFFF
#define C_SPORT2_DB_O           0xFFFFFFFF
#define C_SPORT3_DA_O           0xFFFFFFFF
#define C_SPORT3_DB_O           0xFFFFFFFF

#define C_SPORT0_DA_O           0xFFFFFFFF
#define C_SPORT0_DB_O           0xFFFFFFFF
#define C_SPORT1_DA_O           0xFFFFFFFF
#define C_SPORT1_DB_O           0xFFFFFFFF
#define C_SPORT2_DA_O           0xFFFFFFFF
#define C_SPORT2_DB_O           0xFFFFFFFF
#define C_SPORT3_DA_O           0xFFFFFFFF
#define C_SPORT3_DB_O           0xFFFFFFFF
#define C_SPORT0_CLK_O          0xFFFFFFFF
#define C_SPORT1_CLK_O          0xFFFFFFFF
#define C_SPORT2_CLK_O          0xFFFFFFFF
#define C_SPORT3_CLK_O          0xFFFFFFFF
#define C_SPORT4_CLK_O          0xFFFFFFFF
#define C_SPORT5_CLK_O          0xFFFFFFFF
#define C_TIMER0_O              0xFFFFFFFF
#define C_TIMER1_O              0xFFFFFFFF
#define C_FLAG10_O              0xFFFFFFFF
#define C_MISCB_2_O             0xFFFFFFFF
#define C_MISCB_3_O             0xFFFFFFFF
#define C_MISCB_4_O             0xFFFFFFFF
#define C_MISCB_5_O             0xFFFFFFFF
#define C_FLAG11_O              0xFFFFFFFF
#define C_FLAG12_O              0xFFFFFFFF
#define C_FLAG13_O              0xFFFFFFFF
#define C_FLAG14_O              0xFFFFFFFF
#define C_PCG_CLKA_O            0xFFFFFFFF
#define C_PCG_CLKB_O            0xFFFFFFFF
#define C_FLAG15_O              0xFFFFFFFF

#define C_TIMER0_O              0xFFFFFFFF
#define C_TIMER1_O              0xFFFFFFFF
#define C_PDAP_STRB_O           0xFFFFFFFF
#define C_PCG_CLKA_O            0xFFFFFFFF
#define C_PCG_CLKB_O            0xFFFFFFFF

#define C_MISCA0_O              0xFFFFFFFF
#define C_MISCA1_O              0xFFFFFFFF
#define C_MISCA2_O              0xFFFFFFFF
#define C_MISCA3_O              0xFFFFFFFF
#define C_MISCA4_O              0xFFFFFFFF
#define C_MISCA5_O              0xFFFFFFFF
#define C_SPORT0_CLK_PBEN_O     0xFFFFFFFF
#define C_SPORT0_FS_PBEN_O      0xFFFFFFFF
#define C_SPORT0_DA_PBEN_O      0xFFFFFFFF
#define C_SPORT0_DB_PBEN_O      0xFFFFFFFF
#define C_SPORT1_CLK_PBEN_O     0xFFFFFFFF
#define C_SPORT1_FS_PBEN_O      0xFFFFFFFF
#define C_SPORT1_DA_PBEN_O      0xFFFFFFFF
#define C_SPORT1_DB_PBEN_O      0xFFFFFFFF
#define C_SPORT2_CLK_PBEN_O     0xFFFFFFFF
#define C_SPORT2_FS_PBEN_O      0xFFFFFFFF
#define C_SPORT2_DA_PBEN_O      0xFFFFFFFF
#define C_SPORT2_DB_PBEN_O      0xFFFFFFFF
#define C_SPORT3_CLK_PBEN_O     0xFFFFFFFF
#define C_SPORT3_FS_PBEN_O      0xFFFFFFFF
#define C_SPORT3_DA_PBEN_O      0xFFFFFFFF
#define C_SPORT3_DB_PBEN_O      0xFFFFFFFF
#define C_TIMER0_PBEN_O         0xFFFFFFFF
#define C_TIMER1_PBEN_O         0xFFFFFFFF
#define C_FLAG10_PBEN_O         0xFFFFFFFF
#define C_FLAG11_PBEN_O         0xFFFFFFFF
#define C_FLAG12_PBEN_O         0xFFFFFFFF
#define C_FLAG13_PBEN_O         0xFFFFFFFF
#define C_FLAG14_PBEN_O         0xFFFFFFFF
#define C_FLAG15_PBEN_O         0xFFFFFFFF

#define C_DIR_CLK_O             0xFFFFFFFF
#define C_DIR_TDMCLK_O          0xFFFFFFFF
#define C_DIR_DAT_O             0xFFFFFFFF
#define C_SPIB_MISO_O           0xFFFFFFFF
#define C_SPIB_MOSI_O           0xFFFFFFFF
#define C_SPIB_CLK_O            0xFFFFFFFF
#define C_SPIB_FLG0_O           0xFFFFFFFF
#define C_SPIB_FLG1_O           0xFFFFFFFF
#define C_SPIB_FLG2_O           0xFFFFFFFF
#define C_SPIB_FLG3_O           0xFFFFFFFF
#define C_DIR_LRCLK_FB_O        0xFFFFFFFF
#define C_DIR_LRCLK_REF_O       0xFFFFFFFF
#define C_DIT_O                 0xFFFFFFFF
#define C_SPORT0_TDV_O          0xFFFFFFFF
#define C_SPORT1_TDV_O          0xFFFFFFFF
#define C_SPORT2_TDV_O          0xFFFFFFFF
#define C_SPORT3_TDV_O          0xFFFFFFFF
#define C_PCG_CLKC_O            0xFFFFFFFF
#define C_PCG_CLKD_O            0xFFFFFFFF
#define C_PCG_FSC_O             0xFFFFFFFF
#define C_PCG_FSD_O             0xFFFFFFFF
#define C_SPORT0_TDV_PBEN_O     0xFFFFFFFF
#define C_SPORT1_TDV_PBEN_O     0xFFFFFFFF
#define C_SPORT2_TDV_PBEN_O     0xFFFFFFFF
#define C_SPORT3_TDV_PBEN_O     0xFFFFFFFF
#define C_DPI_PB01_O            0xFFFFFFFF
#define C_DPI_PB02_O            0xFFFFFFFF
#define C_DPI_PB03_O            0xFFFFFFFF
#define C_DPI_PB04_O            0xFFFFFFFF
#define C_DPI_PB05_O            0xFFFFFFFF
#define C_DPI_PB06_O            0xFFFFFFFF
#define C_DPI_PB07_O            0xFFFFFFFF
#define C_DPI_PB08_O            0xFFFFFFFF
#define C_DPI_PB09_O            0xFFFFFFFF
#define C_DPI_PB10_O            0xFFFFFFFF
#define C_DPI_PB11_O            0xFFFFFFFF
#define C_DPI_PB12_O            0xFFFFFFFF
#define C_DPI_PB13_O            0xFFFFFFFF
#define C_DPI_PB14_O            0xFFFFFFFF
#define C_UART0_TX_O            0xFFFFFFFF
#define C_SPI_MISO_O            0xFFFFFFFF
#define C_SPI_MOSI_O            0xFFFFFFFF
#define C_SPI_CLK_O             0xFFFFFFFF
#define C_SPI_FLG0_O            0xFFFFFFFF
#define C_SPI_FLG1_O            0xFFFFFFFF
#define C_SPI_FLG2_O            0xFFFFFFFF
#define C_SPI_FLG3_O            0xFFFFFFFF
#define C_FLAG4_O               0xFFFFFFFF
#define C_FLAG5_O               0xFFFFFFFF
#define C_FLAG6_O               0xFFFFFFFF
#define C_FLAG7_O               0xFFFFFFFF
#define C_FLAG8_O               0xFFFFFFFF
#define C_FLAG9_O               0xFFFFFFFF
#define C_FLAG10_O              0xFFFFFFFF
#define C_FLAG11_O              0xFFFFFFFF
#define C_FLAG12_O              0xFFFFFFFF
#define C_FLAG13_O              0xFFFFFFFF
#define C_FLAG14_O              0xFFFFFFFF
#define C_FLAG15_O              0xFFFFFFFF
#define C_MISC0_O               0xFFFFFFFF
#define C_MISC1_O               0xFFFFFFFF
#define C_MISC2_O               0xFFFFFFFF
#define C_UART0_TX_PBEN_O       0xFFFFFFFF
#define C_SPI_MISO_PBEN_O       0xFFFFFFFF
#define C_SPI_MOSI_PBEN_O       0xFFFFFFFF
#define C_SPI_CLK_PBEN_O        0xFFFFFFFF
#define C_SPI_FLG0_PBEN_O       0xFFFFFFFF
#define C_SPI_FLG1_PBEN_O       0xFFFFFFFF
#define C_SPI_FLG2_PBEN_O       0xFFFFFFFF
#define C_SPI_FLG3_PBEN_O       0xFFFFFFFF
#define C_SPIB_MISO_PBEN_O      0xFFFFFFFF
#define C_SPIB_MOSI_PBEN_O      0xFFFFFFFF
#define C_SPIB_CLK_PBEN_O       0xFFFFFFFF
#define C_SPIB_FLG0_PBEN_O      0xFFFFFFFF
#define C_SPIB_FLG1_PBEN_O      0xFFFFFFFF
#define C_SPIB_FLG2_PBEN_O      0xFFFFFFFF
#define C_SPIB_FLG3_PBEN_O      0xFFFFFFFF
#define C_FLAG4_PBEN_O          0xFFFFFFFF
#define C_FLAG5_PBEN_O          0xFFFFFFFF
#define C_FLAG6_PBEN_O          0xFFFFFFFF
#define C_FLAG7_PBEN_O          0xFFFFFFFF
#define C_FLAG8_PBEN_O          0xFFFFFFFF
#define C_FLAG9_PBEN_O          0xFFFFFFFF
#define C_FLAG10_PBEN_O         0xFFFFFFFF
#define C_FLAG11_PBEN_O         0xFFFFFFFF
#define C_FLAG12_PBEN_O         0xFFFFFFFF
#define C_FLAG13_PBEN_O         0xFFFFFFFF
#define C_FLAG14_PBEN_O         0xFFFFFFFF
#define C_FLAG15_PBEN_O         0xFFFFFFFF
#define C_TWI_DATA_PBEN_O       0xFFFFFFFF
#define C_TWI_CLK_PBEN_O        0xFFFFFFFF
#define C_MISC3_O               0xFFFFFFFF
#define C_MISC4_O               0xFFFFFFFF
#define C_MISC5_O               0xFFFFFFFF
#define C_MISC6_O               0xFFFFFFFF
#define C_MISC7_O               0xFFFFFFFF
#define C_MISC8_O               0xFFFFFFFF



// Group D dummy signals

#define D_MISCA0_O              0xFFFFFFFF
#define D_MISCA1_O              0xFFFFFFFF
#define D_MISCA2_O              0xFFFFFFFF
#define D_MISCA3_O              0xFFFFFFFF
#define D_MISCA4_O              0xFFFFFFFF
#define D_MISCA5_O              0xFFFFFFFF
#define D_SPORT0_CLK_PBEN_O     0xFFFFFFFF
#define D_SPORT0_FS_PBEN_O      0xFFFFFFFF
#define D_SPORT0_DA_PBEN_O      0xFFFFFFFF
#define D_SPORT0_DB_PBEN_O      0xFFFFFFFF
#define D_SPORT1_CLK_PBEN_O     0xFFFFFFFF
#define D_SPORT1_FS_PBEN_O      0xFFFFFFFF
#define D_SPORT1_DA_PBEN_O      0xFFFFFFFF
#define D_SPORT1_DB_PBEN_O      0xFFFFFFFF
#define D_SPORT2_CLK_PBEN_O     0xFFFFFFFF
#define D_SPORT2_FS_PBEN_O      0xFFFFFFFF
#define D_SPORT2_DA_PBEN_O      0xFFFFFFFF
#define D_SPORT2_DB_PBEN_O      0xFFFFFFFF
#define D_SPORT3_CLK_PBEN_O     0xFFFFFFFF
#define D_SPORT3_FS_PBEN_O      0xFFFFFFFF
#define D_SPORT3_DA_PBEN_O      0xFFFFFFFF
#define D_SPORT3_DB_PBEN_O      0xFFFFFFFF
#define D_TIMER0_PBEN_O         0xFFFFFFFF
#define D_TIMER1_PBEN_O         0xFFFFFFFF
#define D_FLAG10_PBEN_O         0xFFFFFFFF
#define D_FLAG11_PBEN_O         0xFFFFFFFF
#define D_FLAG12_PBEN_O         0xFFFFFFFF
#define D_FLAG13_PBEN_O         0xFFFFFFFF
#define D_FLAG14_PBEN_O         0xFFFFFFFF
#define D_FLAG15_PBEN_O         0xFFFFFFFF

#define D_SPORT0_TDV_PBEN_O     0xFFFFFFFF
#define D_SPORT1_TDV_PBEN_O     0xFFFFFFFF
#define D_SPORT2_TDV_PBEN_O     0xFFFFFFFF
#define D_SPORT3_TDV_PBEN_O     0xFFFFFFFF
#define D_DPI_PB01_O            0xFFFFFFFF
#define D_DPI_PB02_O            0xFFFFFFFF
#define D_DPI_PB03_O            0xFFFFFFFF
#define D_DPI_PB04_O            0xFFFFFFFF
#define D_DPI_PB05_O            0xFFFFFFFF
#define D_DPI_PB06_O            0xFFFFFFFF
#define D_DPI_PB07_O            0xFFFFFFFF
#define D_DPI_PB08_O            0xFFFFFFFF
#define D_DPI_PB09_O            0xFFFFFFFF
#define D_DPI_PB10_O            0xFFFFFFFF
#define D_DPI_PB11_O            0xFFFFFFFF
#define D_DPI_PB12_O            0xFFFFFFFF
#define D_DPI_PB13_O            0xFFFFFFFF
#define D_DPI_PB14_O            0xFFFFFFFF
#define D_UART0_TX_O            0xFFFFFFFF
#define D_TIMER0_O              0xFFFFFFFF
#define D_TIMER1_O              0xFFFFFFFF
#define D_SPI_MISO_O            0xFFFFFFFF
#define D_SPI_MOSI_O            0xFFFFFFFF
#define D_SPI_CLK_O             0xFFFFFFFF
#define D_SPI_FLG0_O            0xFFFFFFFF
#define D_SPI_FLG1_O            0xFFFFFFFF
#define D_SPI_FLG2_O            0xFFFFFFFF
#define D_SPI_FLG3_O            0xFFFFFFFF
#define D_FLAG4_O               0xFFFFFFFF
#define D_FLAG5_O               0xFFFFFFFF
#define D_FLAG6_O               0xFFFFFFFF
#define D_FLAG7_O               0xFFFFFFFF
#define D_FLAG8_O               0xFFFFFFFF
#define D_FLAG9_O               0xFFFFFFFF
#define D_FLAG10_O              0xFFFFFFFF
#define D_FLAG11_O              0xFFFFFFFF
#define D_FLAG12_O              0xFFFFFFFF
#define D_FLAG13_O              0xFFFFFFFF
#define D_FLAG14_O              0xFFFFFFFF
#define D_FLAG15_O              0xFFFFFFFF
#define D_SPIB_MISO_O           0xFFFFFFFF
#define D_SPIB_MOSI_O           0xFFFFFFFF
#define D_SPIB_CLK_O            0xFFFFFFFF
#define D_SPIB_FLG0_O           0xFFFFFFFF
#define D_SPIB_FLG1_O           0xFFFFFFFF
#define D_SPIB_FLG2_O           0xFFFFFFFF
#define D_SPIB_FLG3_O           0xFFFFFFFF
#define D_MISC0_O               0xFFFFFFFF
#define D_MISC1_O               0xFFFFFFFF
#define D_MISC2_O               0xFFFFFFFF
#define D_UART0_TX_PBEN_O       0xFFFFFFFF
#define D_SPI_MISO_PBEN_O       0xFFFFFFFF
#define D_SPI_MOSI_PBEN_O       0xFFFFFFFF
#define D_SPI_CLK_PBEN_O        0xFFFFFFFF
#define D_SPI_FLG0_PBEN_O       0xFFFFFFFF
#define D_SPI_FLG1_PBEN_O       0xFFFFFFFF
#define D_SPI_FLG2_PBEN_O       0xFFFFFFFF
#define D_SPI_FLG3_PBEN_O       0xFFFFFFFF
#define D_SPIB_MISO_PBEN_O      0xFFFFFFFF
#define D_SPIB_MOSI_PBEN_O      0xFFFFFFFF
#define D_SPIB_CLK_PBEN_O       0xFFFFFFFF
#define D_SPIB_FLG0_PBEN_O      0xFFFFFFFF
#define D_SPIB_FLG1_PBEN_O      0xFFFFFFFF
#define D_SPIB_FLG2_PBEN_O      0xFFFFFFFF
#define D_SPIB_FLG3_PBEN_O      0xFFFFFFFF
#define D_FLAG4_PBEN_O          0xFFFFFFFF
#define D_FLAG5_PBEN_O          0xFFFFFFFF
#define D_FLAG6_PBEN_O          0xFFFFFFFF
#define D_FLAG7_PBEN_O          0xFFFFFFFF
#define D_FLAG8_PBEN_O          0xFFFFFFFF
#define D_FLAG9_PBEN_O          0xFFFFFFFF
#define D_FLAG10_PBEN_O         0xFFFFFFFF
#define D_FLAG11_PBEN_O         0xFFFFFFFF
#define D_FLAG12_PBEN_O         0xFFFFFFFF
#define D_FLAG13_PBEN_O         0xFFFFFFFF
#define D_FLAG14_PBEN_O         0xFFFFFFFF
#define D_FLAG15_PBEN_O         0xFFFFFFFF
#define D_TWI_DATA_PBEN_O       0xFFFFFFFF
#define D_TWI_CLK_PBEN_O        0xFFFFFFFF
#define D_MISC3_O               0xFFFFFFFF
#define D_MISC4_O               0xFFFFFFFF
#define D_MISC5_O               0xFFFFFFFF
#define D_MISC6_O               0xFFFFFFFF
#define D_MISC7_O               0xFFFFFFFF
#define D_MISC8_O               0xFFFFFFFF


// Group E dummy signals
#define E_SPORT0_CLK_O          0xFFFFFFFF
#define E_SPORT1_CLK_O          0xFFFFFFFF
#define E_SPORT2_CLK_O          0xFFFFFFFF
#define E_SPORT3_CLK_O          0xFFFFFFFF

#define E_SPORT0_DA_O           0xFFFFFFFF
#define E_SPORT0_DB_O           0xFFFFFFFF
#define E_SPORT1_DA_O           0xFFFFFFFF
#define E_SPORT1_DB_O           0xFFFFFFFF
#define E_SPORT2_DA_O           0xFFFFFFFF
#define E_SPORT2_DB_O           0xFFFFFFFF
#define E_SPORT3_DA_O           0xFFFFFFFF
#define E_SPORT3_DB_O           0xFFFFFFFF

#define E_SPORT0_DA_O           0xFFFFFFFF
#define E_SPORT0_DB_O           0xFFFFFFFF
#define E_SPORT1_DA_O           0xFFFFFFFF
#define E_SPORT1_DB_O           0xFFFFFFFF
#define E_SPORT2_DA_O           0xFFFFFFFF
#define E_SPORT2_DB_O           0xFFFFFFFF
#define E_SPORT3_DA_O           0xFFFFFFFF
#define E_SPORT3_DB_O           0xFFFFFFFF
#define E_SPORT0_CLK_O          0xFFFFFFFF
#define E_SPORT1_CLK_O          0xFFFFFFFF
#define E_SPORT2_CLK_O          0xFFFFFFFF
#define E_SPORT3_CLK_O          0xFFFFFFFF
#define E_FLAG10_O              0xFFFFFFFF
#define E_MISCB_2_O             0xFFFFFFFF
#define E_MISCB_3_O             0xFFFFFFFF
#define E_MISCB_4_O             0xFFFFFFFF
#define E_MISCB_5_O             0xFFFFFFFF
#define E_FLAG11_O              0xFFFFFFFF
#define E_FLAG12_O              0xFFFFFFFF
#define E_FLAG13_O              0xFFFFFFFF
#define E_FLAG14_O              0xFFFFFFFF
#define E_FLAG15_O              0xFFFFFFFF

#define E_MISCA0_O              0xFFFFFFFF
#define E_MISCA1_O              0xFFFFFFFF
#define E_MISCA2_O              0xFFFFFFFF
#define E_MISCA3_O              0xFFFFFFFF
#define E_MISCA4_O              0xFFFFFFFF
#define E_MISCA5_O              0xFFFFFFFF
#define E_SPORT0_CLK_PBEN_O     0xFFFFFFFF
#define E_SPORT0_FS_PBEN_O      0xFFFFFFFF
#define E_SPORT0_DA_PBEN_O      0xFFFFFFFF
#define E_SPORT0_DB_PBEN_O      0xFFFFFFFF
#define E_SPORT1_CLK_PBEN_O     0xFFFFFFFF
#define E_SPORT1_FS_PBEN_O      0xFFFFFFFF
#define E_SPORT1_DA_PBEN_O      0xFFFFFFFF
#define E_SPORT1_DB_PBEN_O      0xFFFFFFFF
#define E_SPORT2_CLK_PBEN_O     0xFFFFFFFF
#define E_SPORT2_FS_PBEN_O      0xFFFFFFFF
#define E_SPORT2_DA_PBEN_O      0xFFFFFFFF
#define E_SPORT2_DB_PBEN_O      0xFFFFFFFF
#define E_SPORT3_CLK_PBEN_O     0xFFFFFFFF
#define E_SPORT3_FS_PBEN_O      0xFFFFFFFF
#define E_SPORT3_DA_PBEN_O      0xFFFFFFFF
#define E_SPORT3_DB_PBEN_O      0xFFFFFFFF
#define E_TIMER0_PBEN_O         0xFFFFFFFF
#define E_TIMER1_PBEN_O         0xFFFFFFFF
#define E_FLAG10_PBEN_O         0xFFFFFFFF
#define E_FLAG11_PBEN_O         0xFFFFFFFF
#define E_FLAG12_PBEN_O         0xFFFFFFFF
#define E_FLAG13_PBEN_O         0xFFFFFFFF
#define E_FLAG14_PBEN_O         0xFFFFFFFF
#define E_FLAG15_PBEN_O         0xFFFFFFFF

#define E_DIR_CLK_O             0xFFFFFFFF
#define E_DIR_TDMCLK_O          0xFFFFFFFF
#define E_DIR_DAT_O             0xFFFFFFFF
#define E_DIR_FS_O              0xFFFFFFFF
#define E_DIT_O                 0xFFFFFFFF
#define E_SPIB_MISO_O           0xFFFFFFFF
#define E_SPIB_MOSI_O           0xFFFFFFFF
#define E_SPIB_CLK_O            0xFFFFFFFF
#define E_SPIB_FLG0_O           0xFFFFFFFF
#define E_SPIB_FLG1_O           0xFFFFFFFF
#define E_SPIB_FLG2_O           0xFFFFFFFF
#define E_SPIB_FLG3_O           0xFFFFFFFF
#define E_DIR_LRCLK_FB_O        0xFFFFFFFF
#define E_DIR_LRCLK_REF_O       0xFFFFFFFF
#define E_PDAP_STRB_O           0xFFFFFFFF
#define E_SPORT0_TDV_O          0xFFFFFFFF
#define E_SPORT1_TDV_O          0xFFFFFFFF
#define E_SPORT2_TDV_O          0xFFFFFFFF
#define E_SPORT3_TDV_O          0xFFFFFFFF
#define E_PCG_CLKC_O            0xFFFFFFFF
#define E_PCG_CLKD_O            0xFFFFFFFF
#define E_PCG_FSC_O             0xFFFFFFFF
#define E_PCG_FSD_O             0xFFFFFFFF
#define E_SPORT0_TDV_PBEN_O     0xFFFFFFFF
#define E_SPORT1_TDV_PBEN_O     0xFFFFFFFF
#define E_SPORT2_TDV_PBEN_O     0xFFFFFFFF
#define E_SPORT3_TDV_PBEN_O     0xFFFFFFFF
#define E_DPI_PB01_O            0xFFFFFFFF
#define E_DPI_PB02_O            0xFFFFFFFF
#define E_DPI_PB03_O            0xFFFFFFFF
#define E_DPI_PB04_O            0xFFFFFFFF
#define E_DPI_PB05_O            0xFFFFFFFF
#define E_DPI_PB06_O            0xFFFFFFFF
#define E_DPI_PB07_O            0xFFFFFFFF
#define E_DPI_PB08_O            0xFFFFFFFF
#define E_DPI_PB09_O            0xFFFFFFFF
#define E_DPI_PB10_O            0xFFFFFFFF
#define E_DPI_PB11_O            0xFFFFFFFF
#define E_DPI_PB12_O            0xFFFFFFFF
#define E_DPI_PB13_O            0xFFFFFFFF
#define E_DPI_PB14_O            0xFFFFFFFF
#define E_UART0_TX_O            0xFFFFFFFF
#define E_TIMER0_O              0xFFFFFFFF
#define E_TIMER1_O              0xFFFFFFFF
#define E_SPI_MISO_O            0xFFFFFFFF
#define E_SPI_MOSI_O            0xFFFFFFFF
#define E_SPI_CLK_O             0xFFFFFFFF
#define E_SPI_FLG0_O            0xFFFFFFFF
#define E_SPI_FLG1_O            0xFFFFFFFF
#define E_SPI_FLG2_O            0xFFFFFFFF
#define E_SPI_FLG3_O            0xFFFFFFFF
#define E_FLAG4_O               0xFFFFFFFF
#define E_FLAG5_O               0xFFFFFFFF
#define E_FLAG6_O               0xFFFFFFFF
#define E_FLAG7_O               0xFFFFFFFF
#define E_FLAG8_O               0xFFFFFFFF
#define E_FLAG9_O               0xFFFFFFFF
#define E_FLAG10_O              0xFFFFFFFF
#define E_FLAG11_O              0xFFFFFFFF
#define E_FLAG12_O              0xFFFFFFFF
#define E_FLAG13_O              0xFFFFFFFF
#define E_FLAG14_O              0xFFFFFFFF
#define E_FLAG15_O              0xFFFFFFFF
#define E_MISC0_O               0xFFFFFFFF
#define E_MISC1_O               0xFFFFFFFF
#define E_MISC2_O               0xFFFFFFFF
#define E_UART0_TX_PBEN_O       0xFFFFFFFF
#define E_SPI_MISO_PBEN_O       0xFFFFFFFF
#define E_SPI_MOSI_PBEN_O       0xFFFFFFFF
#define E_SPI_CLK_PBEN_O        0xFFFFFFFF
#define E_SPI_FLG0_PBEN_O       0xFFFFFFFF
#define E_SPI_FLG1_PBEN_O       0xFFFFFFFF
#define E_SPI_FLG2_PBEN_O       0xFFFFFFFF
#define E_SPI_FLG3_PBEN_O       0xFFFFFFFF
#define E_SPIB_MISO_PBEN_O      0xFFFFFFFF
#define E_SPIB_MOSI_PBEN_O      0xFFFFFFFF
#define E_SPIB_CLK_PBEN_O       0xFFFFFFFF
#define E_SPIB_FLG0_PBEN_O      0xFFFFFFFF
#define E_SPIB_FLG1_PBEN_O      0xFFFFFFFF
#define E_SPIB_FLG2_PBEN_O      0xFFFFFFFF
#define E_SPIB_FLG3_PBEN_O      0xFFFFFFFF
#define E_FLAG4_PBEN_O          0xFFFFFFFF
#define E_FLAG5_PBEN_O          0xFFFFFFFF
#define E_FLAG6_PBEN_O          0xFFFFFFFF
#define E_FLAG7_PBEN_O          0xFFFFFFFF
#define E_FLAG8_PBEN_O          0xFFFFFFFF
#define E_FLAG9_PBEN_O          0xFFFFFFFF
#define E_FLAG10_PBEN_O         0xFFFFFFFF
#define E_FLAG11_PBEN_O         0xFFFFFFFF
#define E_FLAG12_PBEN_O         0xFFFFFFFF
#define E_FLAG13_PBEN_O         0xFFFFFFFF
#define E_FLAG14_PBEN_O         0xFFFFFFFF
#define E_FLAG15_PBEN_O         0xFFFFFFFF
#define E_TWI_DATA_PBEN_O       0xFFFFFFFF
#define E_TWI_CLK_PBEN_O        0xFFFFFFFF
#define E_MISC3_O               0xFFFFFFFF
#define E_MISC4_O               0xFFFFFFFF
#define E_MISC5_O               0xFFFFFFFF
#define E_MISC6_O               0xFFFFFFFF
#define E_MISC7_O               0xFFFFFFFF
#define E_MISC8_O               0xFFFFFFFF



// Group F dummy signals
#define F_DAI_PB01_O            0xFFFFFFFF
#define F_DAI_PB02_O            0xFFFFFFFF
#define F_DAI_PB03_O            0xFFFFFFFF
#define F_DAI_PB04_O            0xFFFFFFFF
#define F_DAI_PB05_O            0xFFFFFFFF
#define F_DAI_PB06_O            0xFFFFFFFF
#define F_DAI_PB07_O            0xFFFFFFFF
#define F_DAI_PB08_O            0xFFFFFFFF
#define F_DAI_PB09_O            0xFFFFFFFF
#define F_DAI_PB10_O            0xFFFFFFFF
#define F_DAI_PB11_O            0xFFFFFFFF
#define F_DAI_PB12_O            0xFFFFFFFF
#define F_DAI_PB13_O            0xFFFFFFFF
#define F_DAI_PB14_O            0xFFFFFFFF
#define F_DAI_PB15_O            0xFFFFFFFF
#define F_DAI_PB16_O            0xFFFFFFFF
#define F_DAI_PB17_O            0xFFFFFFFF
#define F_DAI_PB18_O            0xFFFFFFFF
#define F_DAI_PB19_O            0xFFFFFFFF
#define F_DAI_PB20_O            0xFFFFFFFF
#define F_SPORT0_CLK_O          0xFFFFFFFF
#define F_SPORT1_CLK_O          0xFFFFFFFF
#define F_SPORT2_CLK_O          0xFFFFFFFF
#define F_SPORT3_CLK_O          0xFFFFFFFF
#define F_PCG_CLKA_O            0xFFFFFFFF
#define F_PCG_CLKB_O            0xFFFFFFFF

#define F_SPORT0_DA_O           0xFFFFFFFF
#define F_SPORT0_DB_O           0xFFFFFFFF
#define F_SPORT1_DA_O           0xFFFFFFFF
#define F_SPORT1_DB_O           0xFFFFFFFF
#define F_SPORT2_DA_O           0xFFFFFFFF
#define F_SPORT2_DB_O           0xFFFFFFFF
#define F_SPORT3_DA_O           0xFFFFFFFF
#define F_SPORT3_DB_O           0xFFFFFFFF


#define F_SPORT0_FS_O           0xFFFFFFFF
#define F_SPORT1_FS_O           0xFFFFFFFF
#define F_SPORT2_FS_O           0xFFFFFFFF
#define F_SPORT3_FS_O           0xFFFFFFFF
#define F_PCG_FSA_O             0xFFFFFFFF
#define F_PCG_FSB_O             0xFFFFFFFF

#define F_SPORT0_DA_O           0xFFFFFFFF
#define F_SPORT0_DB_O           0xFFFFFFFF
#define F_SPORT1_DA_O           0xFFFFFFFF
#define F_SPORT1_DB_O           0xFFFFFFFF
#define F_SPORT2_DA_O           0xFFFFFFFF
#define F_SPORT2_DB_O           0xFFFFFFFF
#define F_SPORT3_DA_O           0xFFFFFFFF
#define F_SPORT3_DB_O           0xFFFFFFFF
#define F_SPORT0_CLK_O          0xFFFFFFFF
#define F_SPORT1_CLK_O          0xFFFFFFFF
#define F_SPORT2_CLK_O          0xFFFFFFFF
#define F_SPORT3_CLK_O          0xFFFFFFFF
#define F_SPORT0_FS_O           0xFFFFFFFF
#define F_SPORT1_FS_O           0xFFFFFFFF
#define F_SPORT2_FS_O           0xFFFFFFFF
#define F_SPORT3_FS_O           0xFFFFFFFF
#define F_TIMER0_O              0xFFFFFFFF
#define F_TIMER1_O              0xFFFFFFFF
#define F_FLAG10_O              0xFFFFFFFF
#define F_MISCB_2_O             0xFFFFFFFF
#define F_MISCB_3_O             0xFFFFFFFF
#define F_MISCB_4_O             0xFFFFFFFF
#define F_MISCB_5_O             0xFFFFFFFF
#define F_FLAG11_O              0xFFFFFFFF
#define F_FLAG12_O              0xFFFFFFFF
#define F_FLAG13_O              0xFFFFFFFF
#define F_FLAG14_O              0xFFFFFFFF
#define F_PCG_CLKA_O            0xFFFFFFFF
#define F_PCG_CLKB_O            0xFFFFFFFF
#define F_PCG_FSA_O             0xFFFFFFFF
#define F_PCG_FSB_O             0xFFFFFFFF
#define F_FLAG15_O              0xFFFFFFFF

#define F_TIMER0_O              0xFFFFFFFF
#define F_TIMER1_O              0xFFFFFFFF
#define F_PDAP_STRB_O           0xFFFFFFFF
#define F_PCG_CLKA_O            0xFFFFFFFF
#define F_PCG_FSA_O             0xFFFFFFFF
#define F_PCG_CLKB_O            0xFFFFFFFF
#define F_PCG_FSB_O             0xFFFFFFFF

#define F_DIR_CLK_O             0xFFFFFFFF
#define F_DIR_TDMCLK_O          0xFFFFFFFF
#define F_DIR_DAT_O             0xFFFFFFFF
#define F_DIR_FS_O              0xFFFFFFFF
#define F_DIT_O                 0xFFFFFFFF
#define F_DIR_LRCLK_FB_O        0xFFFFFFFF
#define F_DIR_LRCLK_REF_O       0xFFFFFFFF
#define F_SPORT0_TDV_O          0xFFFFFFFF
#define F_SPORT1_TDV_O          0xFFFFFFFF
#define F_SPORT2_TDV_O          0xFFFFFFFF
#define F_SPORT3_TDV_O          0xFFFFFFFF
#define F_PCG_CLKC_O            0xFFFFFFFF
#define F_PCG_CLKD_O            0xFFFFFFFF
#define F_PCG_FSC_O             0xFFFFFFFF
#define F_PCG_FSD_O             0xFFFFFFFF
#define F_DPI_PB01_O            0xFFFFFFFF
#define F_DPI_PB02_O            0xFFFFFFFF
#define F_DPI_PB03_O            0xFFFFFFFF
#define F_DPI_PB04_O            0xFFFFFFFF
#define F_DPI_PB05_O            0xFFFFFFFF
#define F_DPI_PB06_O            0xFFFFFFFF
#define F_DPI_PB07_O            0xFFFFFFFF
#define F_DPI_PB08_O            0xFFFFFFFF
#define F_DPI_PB09_O            0xFFFFFFFF
#define F_DPI_PB10_O            0xFFFFFFFF
#define F_DPI_PB11_O            0xFFFFFFFF
#define F_DPI_PB12_O            0xFFFFFFFF
#define F_DPI_PB13_O            0xFFFFFFFF
#define F_DPI_PB14_O            0xFFFFFFFF
#define F_UART0_TX_O            0xFFFFFFFF
#define F_SPI_MISO_O            0xFFFFFFFF
#define F_SPI_MOSI_O            0xFFFFFFFF
#define F_SPI_CLK_O             0xFFFFFFFF
#define F_SPI_FLG0_O            0xFFFFFFFF
#define F_SPI_FLG1_O            0xFFFFFFFF
#define F_SPI_FLG2_O            0xFFFFFFFF
#define F_SPI_FLG3_O            0xFFFFFFFF
#define F_FLAG4_O               0xFFFFFFFF
#define F_FLAG5_O               0xFFFFFFFF
#define F_FLAG6_O               0xFFFFFFFF
#define F_FLAG7_O               0xFFFFFFFF
#define F_FLAG8_O               0xFFFFFFFF
#define F_FLAG9_O               0xFFFFFFFF
#define F_FLAG10_O              0xFFFFFFFF
#define F_FLAG11_O              0xFFFFFFFF
#define F_FLAG12_O              0xFFFFFFFF
#define F_FLAG13_O              0xFFFFFFFF
#define F_FLAG14_O              0xFFFFFFFF
#define F_FLAG15_O              0xFFFFFFFF
#define F_SPIB_MISO_O           0xFFFFFFFF
#define F_SPIB_MOSI_O           0xFFFFFFFF
#define F_SPIB_CLK_O            0xFFFFFFFF
#define F_SPIB_FLG0_O           0xFFFFFFFF
#define F_SPIB_FLG1_O           0xFFFFFFFF
#define F_SPIB_FLG2_O           0xFFFFFFFF
#define F_SPIB_FLG3_O           0xFFFFFFFF
#define F_MISC0_O               0xFFFFFFFF
#define F_MISC1_O               0xFFFFFFFF
#define F_MISC2_O               0xFFFFFFFF
#define F_TIMER0_PBEN_O         0xFFFFFFFF
#define F_TIMER1_PBEN_O         0xFFFFFFFF
#define F_UART0_TX_PBEN_O       0xFFFFFFFF
#define F_SPI_MISO_PBEN_O       0xFFFFFFFF
#define F_SPI_MOSI_PBEN_O       0xFFFFFFFF
#define F_SPI_CLK_PBEN_O        0xFFFFFFFF
#define F_SPI_FLG0_PBEN_O       0xFFFFFFFF
#define F_SPI_FLG1_PBEN_O       0xFFFFFFFF
#define F_SPI_FLG2_PBEN_O       0xFFFFFFFF
#define F_SPI_FLG3_PBEN_O       0xFFFFFFFF
#define F_SPIB_MISO_PBEN_O      0xFFFFFFFF
#define F_SPIB_MOSI_PBEN_O      0xFFFFFFFF
#define F_SPIB_CLK_PBEN_O       0xFFFFFFFF
#define F_SPIB_FLG0_PBEN_O      0xFFFFFFFF
#define F_SPIB_FLG1_PBEN_O      0xFFFFFFFF
#define F_SPIB_FLG2_PBEN_O      0xFFFFFFFF
#define F_SPIB_FLG3_PBEN_O      0xFFFFFFFF
#define F_FLAG4_PBEN_O          0xFFFFFFFF
#define F_FLAG5_PBEN_O          0xFFFFFFFF
#define F_FLAG6_PBEN_O          0xFFFFFFFF
#define F_FLAG7_PBEN_O          0xFFFFFFFF
#define F_FLAG8_PBEN_O          0xFFFFFFFF
#define F_FLAG9_PBEN_O          0xFFFFFFFF
#define F_FLAG10_PBEN_O         0xFFFFFFFF
#define F_FLAG11_PBEN_O         0xFFFFFFFF
#define F_FLAG12_PBEN_O         0xFFFFFFFF
#define F_FLAG13_PBEN_O         0xFFFFFFFF
#define F_FLAG14_PBEN_O         0xFFFFFFFF
#define F_FLAG15_PBEN_O         0xFFFFFFFF
#define F_TWI_DATA_PBEN_O       0xFFFFFFFF
#define F_TWI_CLK_PBEN_O        0xFFFFFFFF
#define F_MISC3_O               0xFFFFFFFF
#define F_MISC4_O               0xFFFFFFFF
#define F_MISC5_O               0xFFFFFFFF
#define F_MISC6_O               0xFFFFFFFF
#define F_MISC7_O               0xFFFFFFFF
#define F_MISC8_O               0xFFFFFFFF




// Group G dummy signals
#define G_DAI_PB01_O            0xFFFFFFFF
#define G_DAI_PB02_O            0xFFFFFFFF
#define G_DAI_PB03_O            0xFFFFFFFF
#define G_DAI_PB04_O            0xFFFFFFFF
#define G_DAI_PB05_O            0xFFFFFFFF
#define G_DAI_PB06_O            0xFFFFFFFF
#define G_DAI_PB07_O            0xFFFFFFFF
#define G_DAI_PB08_O            0xFFFFFFFF
#define G_DAI_PB09_O            0xFFFFFFFF
#define G_DAI_PB10_O            0xFFFFFFFF
#define G_DAI_PB11_O            0xFFFFFFFF
#define G_DAI_PB12_O            0xFFFFFFFF
#define G_DAI_PB13_O            0xFFFFFFFF
#define G_DAI_PB14_O            0xFFFFFFFF
#define G_DAI_PB15_O            0xFFFFFFFF
#define G_DAI_PB16_O            0xFFFFFFFF
#define G_DAI_PB17_O            0xFFFFFFFF
#define G_DAI_PB18_O            0xFFFFFFFF
#define G_DAI_PB19_O            0xFFFFFFFF
#define G_DAI_PB20_O            0xFFFFFFFF
#define G_SPORT0_CLK_O          0xFFFFFFFF
#define G_SPORT1_CLK_O          0xFFFFFFFF
#define G_SPORT2_CLK_O          0xFFFFFFFF
#define G_SPORT3_CLK_O          0xFFFFFFFF
#define G_PCG_CLKA_O            0xFFFFFFFF
#define G_PCG_CLKB_O            0xFFFFFFFF

#define G_SPORT0_DA_O           0xFFFFFFFF
#define G_SPORT0_DB_O           0xFFFFFFFF
#define G_SPORT1_DA_O           0xFFFFFFFF
#define G_SPORT1_DB_O           0xFFFFFFFF
#define G_SPORT2_DA_O           0xFFFFFFFF
#define G_SPORT2_DB_O           0xFFFFFFFF
#define G_SPORT3_DA_O           0xFFFFFFFF
#define G_SPORT3_DB_O           0xFFFFFFFF

#define G_SPORT0_FS_O           0xFFFFFFFF
#define G_SPORT1_FS_O           0xFFFFFFFF
#define G_SPORT2_FS_O           0xFFFFFFFF
#define G_SPORT3_FS_O           0xFFFFFFFF
#define G_PCG_FSA_O             0xFFFFFFFF
#define G_PCG_FSB_O             0xFFFFFFFF

#define G_TIMER0_O              0xFFFFFFFF
#define G_TIMER1_O              0xFFFFFFFF
#define G_FLAG10_O              0xFFFFFFFF
#define G_MISCB_2_O             0xFFFFFFFF
#define G_MISCB_3_O             0xFFFFFFFF
#define G_MISCB_4_O             0xFFFFFFFF
#define G_MISCB_5_O             0xFFFFFFFF
#define G_FLAG11_O              0xFFFFFFFF
#define G_FLAG12_O              0xFFFFFFFF
#define G_FLAG13_O              0xFFFFFFFF
#define G_FLAG14_O              0xFFFFFFFF
#define G_PCG_FSA_O             0xFFFFFFFF
#define G_PCG_FSB_O             0xFFFFFFFF
#define G_FLAG15_O              0xFFFFFFFF

#define G_TIMER0_O              0xFFFFFFFF
#define G_TIMER1_O              0xFFFFFFFF
#define G_PDAP_STRB_O           0xFFFFFFFF
#define G_PCG_FSA_O             0xFFFFFFFF
#define G_PCG_FSB_O             0xFFFFFFFF

#define G_MISCA0_O              0xFFFFFFFF
#define G_MISCA1_O              0xFFFFFFFF
#define G_MISCA2_O              0xFFFFFFFF
#define G_MISCA3_O              0xFFFFFFFF
#define G_MISCA4_O              0xFFFFFFFF
#define G_MISCA5_O              0xFFFFFFFF
#define G_SPORT0_CLK_PBEN_O     0xFFFFFFFF
#define G_SPORT0_FS_PBEN_O      0xFFFFFFFF
#define G_SPORT0_DA_PBEN_O      0xFFFFFFFF
#define G_SPORT0_DB_PBEN_O      0xFFFFFFFF
#define G_SPORT1_CLK_PBEN_O     0xFFFFFFFF
#define G_SPORT1_FS_PBEN_O      0xFFFFFFFF
#define G_SPORT1_DA_PBEN_O      0xFFFFFFFF
#define G_SPORT1_DB_PBEN_O      0xFFFFFFFF
#define G_SPORT2_CLK_PBEN_O     0xFFFFFFFF
#define G_SPORT2_FS_PBEN_O      0xFFFFFFFF
#define G_SPORT2_DA_PBEN_O      0xFFFFFFFF
#define G_SPORT2_DB_PBEN_O      0xFFFFFFFF
#define G_SPORT3_CLK_PBEN_O     0xFFFFFFFF
#define G_SPORT3_FS_PBEN_O      0xFFFFFFFF
#define G_SPORT3_DA_PBEN_O      0xFFFFFFFF
#define G_SPORT3_DB_PBEN_O      0xFFFFFFFF
#define G_TIMER0_PBEN_O         0xFFFFFFFF
#define G_TIMER1_PBEN_O         0xFFFFFFFF
#define G_FLAG10_PBEN_O         0xFFFFFFFF
#define G_FLAG11_PBEN_O         0xFFFFFFFF
#define G_FLAG12_PBEN_O         0xFFFFFFFF
#define G_FLAG13_PBEN_O         0xFFFFFFFF
#define G_FLAG14_PBEN_O         0xFFFFFFFF
#define G_FLAG15_PBEN_O         0xFFFFFFFF

#define G_DIR_CLK_O             0xFFFFFFFF
#define G_DIR_TDMCLK_O          0xFFFFFFFF
#define G_DIR_DAT_O             0xFFFFFFFF
#define G_DIR_FS_O              0xFFFFFFFF
#define G_DIT_O                 0xFFFFFFFF
#define G_SPIB_MISO_O           0xFFFFFFFF
#define G_SPIB_MOSI_O           0xFFFFFFFF
#define G_SPIB_CLK_O            0xFFFFFFFF
#define G_SPIB_FLG0_O           0xFFFFFFFF
#define G_SPIB_FLG1_O           0xFFFFFFFF
#define G_SPIB_FLG2_O           0xFFFFFFFF
#define G_SPIB_FLG3_O           0xFFFFFFFF
#define G_DIR_LRCLK_FB_O        0xFFFFFFFF
#define G_DIR_LRCLK_REF_O       0xFFFFFFFF
#define G_SPORT0_TDV_O          0xFFFFFFFF
#define G_SPORT1_TDV_O          0xFFFFFFFF
#define G_SPORT2_TDV_O          0xFFFFFFFF
#define G_SPORT3_TDV_O          0xFFFFFFFF
#define G_PCG_CLKC_O            0xFFFFFFFF
#define G_PCG_CLKD_O            0xFFFFFFFF
#define G_PCG_FSC_O             0xFFFFFFFF
#define G_PCG_FSD_O             0xFFFFFFFF
#define G_SPORT0_TDV_PBEN_O     0xFFFFFFFF
#define G_SPORT1_TDV_PBEN_O     0xFFFFFFFF
#define G_SPORT2_TDV_PBEN_O     0xFFFFFFFF
#define G_SPORT3_TDV_PBEN_O     0xFFFFFFFF
#define G_DPI_PB01_O            0xFFFFFFFF
#define G_DPI_PB02_O            0xFFFFFFFF
#define G_DPI_PB03_O            0xFFFFFFFF
#define G_DPI_PB04_O            0xFFFFFFFF
#define G_DPI_PB05_O            0xFFFFFFFF
#define G_DPI_PB06_O            0xFFFFFFFF
#define G_DPI_PB07_O            0xFFFFFFFF
#define G_DPI_PB08_O            0xFFFFFFFF
#define G_DPI_PB09_O            0xFFFFFFFF
#define G_DPI_PB10_O            0xFFFFFFFF
#define G_DPI_PB11_O            0xFFFFFFFF
#define G_DPI_PB12_O            0xFFFFFFFF
#define G_DPI_PB13_O            0xFFFFFFFF
#define G_DPI_PB14_O            0xFFFFFFFF
#define G_UART0_TX_O            0xFFFFFFFF
#define G_SPI_MISO_O            0xFFFFFFFF
#define G_SPI_MOSI_O            0xFFFFFFFF
#define G_SPI_CLK_O             0xFFFFFFFF
#define G_SPI_FLG0_O            0xFFFFFFFF
#define G_SPI_FLG1_O            0xFFFFFFFF
#define G_SPI_FLG2_O            0xFFFFFFFF
#define G_SPI_FLG3_O            0xFFFFFFFF
#define G_FLAG4_O               0xFFFFFFFF
#define G_FLAG5_O               0xFFFFFFFF
#define G_FLAG6_O               0xFFFFFFFF
#define G_FLAG7_O               0xFFFFFFFF
#define G_FLAG8_O               0xFFFFFFFF
#define G_FLAG9_O               0xFFFFFFFF
#define G_FLAG10_O              0xFFFFFFFF
#define G_FLAG11_O              0xFFFFFFFF
#define G_FLAG12_O              0xFFFFFFFF
#define G_FLAG13_O              0xFFFFFFFF
#define G_FLAG14_O              0xFFFFFFFF
#define G_FLAG15_O              0xFFFFFFFF
#define G_MISC0_O               0xFFFFFFFF
#define G_MISC1_O               0xFFFFFFFF
#define G_MISC2_O               0xFFFFFFFF
#define G_UART0_TX_PBEN_O       0xFFFFFFFF
#define G_SPI_MISO_PBEN_O       0xFFFFFFFF
#define G_SPI_MOSI_PBEN_O       0xFFFFFFFF
#define G_SPI_CLK_PBEN_O        0xFFFFFFFF
#define G_SPI_FLG0_PBEN_O       0xFFFFFFFF
#define G_SPI_FLG1_PBEN_O       0xFFFFFFFF
#define G_SPI_FLG2_PBEN_O       0xFFFFFFFF
#define G_SPI_FLG3_PBEN_O       0xFFFFFFFF
#define G_SPIB_MISO_PBEN_O      0xFFFFFFFF
#define G_SPIB_MOSI_PBEN_O      0xFFFFFFFF
#define G_SPIB_CLK_PBEN_O       0xFFFFFFFF
#define G_SPIB_FLG0_PBEN_O      0xFFFFFFFF
#define G_SPIB_FLG1_PBEN_O      0xFFFFFFFF
#define G_SPIB_FLG2_PBEN_O      0xFFFFFFFF
#define G_SPIB_FLG3_PBEN_O      0xFFFFFFFF
#define G_FLAG4_PBEN_O          0xFFFFFFFF
#define G_FLAG5_PBEN_O          0xFFFFFFFF
#define G_FLAG6_PBEN_O          0xFFFFFFFF
#define G_FLAG7_PBEN_O          0xFFFFFFFF
#define G_FLAG8_PBEN_O          0xFFFFFFFF
#define G_FLAG9_PBEN_O          0xFFFFFFFF
#define G_FLAG10_PBEN_O         0xFFFFFFFF
#define G_FLAG11_PBEN_O         0xFFFFFFFF
#define G_FLAG12_PBEN_O         0xFFFFFFFF
#define G_FLAG13_PBEN_O         0xFFFFFFFF
#define G_FLAG14_PBEN_O         0xFFFFFFFF
#define G_FLAG15_PBEN_O         0xFFFFFFFF
#define G_TWI_DATA_PBEN_O       0xFFFFFFFF
#define G_TWI_CLK_PBEN_O        0xFFFFFFFF
#define G_MISC3_O               0xFFFFFFFF
#define G_MISC4_O               0xFFFFFFFF
#define G_MISC5_O               0xFFFFFFFF
#define G_MISC6_O               0xFFFFFFFF
#define G_MISC7_O               0xFFFFFFFF
#define G_MISC8_O               0xFFFFFFFF


//A2 DUMMY SIGNALS
#define A2_DAI_PB01_O            0xFFFFFFFF
#define A2_DAI_PB02_O            0xFFFFFFFF
#define A2_DAI_PB03_O            0xFFFFFFFF
#define A2_DAI_PB04_O            0xFFFFFFFF
#define A2_DAI_PB05_O            0xFFFFFFFF
#define A2_DAI_PB06_O            0xFFFFFFFF
#define A2_DAI_PB07_O            0xFFFFFFFF
#define A2_DAI_PB08_O            0xFFFFFFFF
#define A2_DAI_PB09_O            0xFFFFFFFF
#define A2_DAI_PB10_O            0xFFFFFFFF
#define A2_DAI_PB11_O            0xFFFFFFFF
#define A2_DAI_PB12_O            0xFFFFFFFF
#define A2_DAI_PB13_O            0xFFFFFFFF
#define A2_DAI_PB14_O            0xFFFFFFFF
#define A2_DAI_PB15_O            0xFFFFFFFF
#define A2_DAI_PB16_O            0xFFFFFFFF
#define A2_DAI_PB17_O            0xFFFFFFFF
#define A2_DAI_PB18_O            0xFFFFFFFF
#define A2_DAI_PB19_O            0xFFFFFFFF
#define A2_DAI_PB20_O            0xFFFFFFFF
#define A2_SPORT0_CLK_O          0xFFFFFFFF
#define A2_SPORT1_CLK_O          0xFFFFFFFF
#define A2_SPORT2_CLK_O          0xFFFFFFFF
#define A2_SPORT3_CLK_O          0xFFFFFFFF
#define A2_DIR_CLK_O             0xFFFFFFFF
#define A2_DIR_TDMCLK_O          0xFFFFFFFF
#define A2_PCG_CLKA_O            0xFFFFFFFF
#define A2_PCG_CLKB_O            0xFFFFFFFF
#define A2_SPORT0_DA_O           0xFFFFFFFF
#define A2_SPORT0_DB_O           0xFFFFFFFF
#define A2_SPORT1_DA_O           0xFFFFFFFF
#define A2_SPORT1_DB_O           0xFFFFFFFF
#define A2_SPORT2_DA_O           0xFFFFFFFF
#define A2_SPORT2_DB_O           0xFFFFFFFF
#define A2_SPORT3_DA_O           0xFFFFFFFF
#define A2_SPORT3_DB_O           0xFFFFFFFF
#define A2_DIR_DAT_O             0xFFFFFFFF
#define A2_SPORT0_FS_O           0xFFFFFFFF
#define A2_SPORT1_FS_O           0xFFFFFFFF
#define A2_SPORT2_FS_O           0xFFFFFFFF
#define A2_SPORT3_FS_O           0xFFFFFFFF
#define A2_PCG_FSA_O             0xFFFFFFFF
#define A2_PCG_FSB_O             0xFFFFFFFF
#define A2_DIT_O                 0xFFFFFFFF
#define A2_DIR_FS_O              0xFFFFFFFF
#define A2_PDAP_STRB_O           0xFFFFFFFF
#define A2_SPORT0_TDV_O          0xFFFFFFFF
#define A2_SPORT1_TDV_O          0xFFFFFFFF
#define A2_SPORT2_TDV_O          0xFFFFFFFF
#define A2_SPORT3_TDV_O          0xFFFFFFFF
#define A2_DIR_LRCLK_FB_O        0xFFFFFFFF
#define A2_DIR_LRCLK_REF_O       0xFFFFFFFF
#define A2_PCG_CLKC_O            0xFFFFFFFF
#define A2_PCG_CLKD_O            0xFFFFFFFF
#define A2_PCG_FSC_O             0xFFFFFFFF
#define A2_PCG_FSD_O             0xFFFFFFFF
#define A2_MISCA0_O              0xFFFFFFFF
#define A2_MISCA1_O              0xFFFFFFFF
#define A2_MISCA2_O              0xFFFFFFFF
#define A2_MISCA3_O              0xFFFFFFFF
#define A2_MISCA4_O              0xFFFFFFFF
#define A2_MISCA5_O              0xFFFFFFFF
#define A2_SPORT0_CLK_PBEN_O     0xFFFFFFFF
#define A2_SPORT0_FS_PBEN_O      0xFFFFFFFF
#define A2_SPORT0_DA_PBEN_O      0xFFFFFFFF
#define A2_SPORT0_DB_PBEN_O      0xFFFFFFFF
#define A2_SPORT1_CLK_PBEN_O     0xFFFFFFFF
#define A2_SPORT1_FS_PBEN_O      0xFFFFFFFF
#define A2_SPORT1_DA_PBEN_O      0xFFFFFFFF
#define A2_SPORT1_DB_PBEN_O      0xFFFFFFFF
#define A2_SPORT2_CLK_PBEN_O     0xFFFFFFFF
#define A2_SPORT2_FS_PBEN_O      0xFFFFFFFF
#define A2_SPORT2_DA_PBEN_O      0xFFFFFFFF
#define A2_SPORT2_DB_PBEN_O      0xFFFFFFFF
#define A2_SPORT3_CLK_PBEN_O     0xFFFFFFFF
#define A2_SPORT3_FS_PBEN_O      0xFFFFFFFF
#define A2_SPORT3_DA_PBEN_O      0xFFFFFFFF
#define A2_SPORT3_DB_PBEN_O      0xFFFFFFFF
#define A2_SPORT0_TDV_PBEN_O     0xFFFFFFFF
#define A2_SPORT1_TDV_PBEN_O     0xFFFFFFFF
#define A2_SPORT2_TDV_PBEN_O     0xFFFFFFFF
#define A2_SPORT3_TDV_PBEN_O     0xFFFFFFFF
#define A2_SPI_MISO_O            0xFFFFFFFF
#define A2_SPI_MOSI_O            0xFFFFFFFF
#define A2_SPI_CLK_O             0xFFFFFFFF
#define A2_SPI_FLG0_O            0xFFFFFFFF
#define A2_SPI_FLG1_O            0xFFFFFFFF
#define A2_SPI_FLG2_O            0xFFFFFFFF
#define A2_SPI_FLG3_O            0xFFFFFFFF
#define A2_FLAG4_O               0xFFFFFFFF
#define A2_FLAG5_O               0xFFFFFFFF
#define A2_FLAG6_O               0xFFFFFFFF
#define A2_FLAG7_O               0xFFFFFFFF
#define A2_FLAG8_O               0xFFFFFFFF
#define A2_FLAG9_O               0xFFFFFFFF
#define A2_FLAG10_O              0xFFFFFFFF
#define A2_FLAG11_O              0xFFFFFFFF
#define A2_FLAG12_O              0xFFFFFFFF
#define A2_FLAG13_O              0xFFFFFFFF
#define A2_FLAG14_O              0xFFFFFFFF
#define A2_FLAG15_O              0xFFFFFFFF
#define A2_SPIB_MISO_O           0xFFFFFFFF
#define A2_SPIB_MOSI_O           0xFFFFFFFF
#define A2_SPIB_CLK_O            0xFFFFFFFF
#define A2_SPIB_FLG0_O           0xFFFFFFFF
#define A2_SPIB_FLG1_O           0xFFFFFFFF
#define A2_SPIB_FLG2_O           0xFFFFFFFF
#define A2_SPIB_FLG3_O           0xFFFFFFFF
#define A2_MISC0_O               0xFFFFFFFF
#define A2_MISC1_O               0xFFFFFFFF
#define A2_MISC2_O              0xFFFFFFFF
#define A2_TIMER0_PBEN_O        0xFFFFFFFF
#define A2_TIMER1_PBEN_O        0xFFFFFFFF
#define A2_UART0_TX_PBEN_O      0xFFFFFFFF
#define A2_SPI_MISO_PBEN_O      0xFFFFFFFF
#define A2_SPI_MOSI_PBEN_O      0xFFFFFFFF
#define A2_SPI_CLK_PBEN_O       0xFFFFFFFF
#define A2_SPI_FLG0_PBEN_O      0xFFFFFFFF
#define A2_SPI_FLG1_PBEN_O      0xFFFFFFFF
#define A2_SPI_FLG2_PBEN_O      0xFFFFFFFF
#define A2_SPI_FLG3_PBEN_O      0xFFFFFFFF
#define A2_SPIB_MISO_PBEN_O     0xFFFFFFFF
#define A2_SPIB_MOSI_PBEN_O     0xFFFFFFFF
#define A2_SPIB_CLK_PBEN_O      0xFFFFFFFF
#define A2_SPIB_FLG0_PBEN_O     0xFFFFFFFF
#define A2_SPIB_FLG1_PBEN_O     0xFFFFFFFF
#define A2_SPIB_FLG2_PBEN_O     0xFFFFFFFF
#define A2_SPIB_FLG3_PBEN_O     0xFFFFFFFF
#define A2_FLAG4_PBEN_O         0xFFFFFFFF
#define A2_FLAG5_PBEN_O         0xFFFFFFFF
#define A2_FLAG6_PBEN_O         0xFFFFFFFF
#define A2_FLAG7_PBEN_O         0xFFFFFFFF
#define A2_FLAG8_PBEN_O         0xFFFFFFFF
#define A2_FLAG9_PBEN_O         0xFFFFFFFF
#define A2_FLAG10_PBEN_O        0xFFFFFFFF
#define A2_FLAG11_PBEN_O        0xFFFFFFFF
#define A2_FLAG12_PBEN_O        0xFFFFFFFF
#define A2_FLAG13_PBEN_O        0xFFFFFFFF
#define A2_FLAG14_PBEN_O        0xFFFFFFFF
#define A2_FLAG15_PBEN_O        0xFFFFFFFF
#define A2_TWI_DATA_PBEN_O      0xFFFFFFFF
#define A2_TWI_CLK_PBEN_O       0xFFFFFFFF
#define A2_MISC3_O              0xFFFFFFFF
#define A2_MISC4_O              0xFFFFFFFF
#define A2_MISC5_O              0xFFFFFFFF
#define A2_MISC6_O              0xFFFFFFFF
#define A2_MISC7_O              0xFFFFFFFF
#define A2_MISC8_O              0xFFFFFFFF



//B2 DUMMY SIGNALS
#define B2_DAI_PB01_O            0xFFFFFFFF
#define B2_DAI_PB02_O            0xFFFFFFFF
#define B2_DAI_PB03_O            0xFFFFFFFF
#define B2_DAI_PB04_O            0xFFFFFFFF
#define B2_DAI_PB05_O            0xFFFFFFFF
#define B2_DAI_PB06_O            0xFFFFFFFF
#define B2_DAI_PB07_O            0xFFFFFFFF
#define B2_DAI_PB08_O            0xFFFFFFFF
#define B2_DAI_PB09_O            0xFFFFFFFF
#define B2_DAI_PB10_O            0xFFFFFFFF
#define B2_DAI_PB11_O            0xFFFFFFFF
#define B2_DAI_PB12_O            0xFFFFFFFF
#define B2_DAI_PB13_O            0xFFFFFFFF
#define B2_DAI_PB14_O            0xFFFFFFFF
#define B2_DAI_PB15_O            0xFFFFFFFF
#define B2_DAI_PB16_O            0xFFFFFFFF
#define B2_DAI_PB17_O            0xFFFFFFFF
#define B2_DAI_PB18_O            0xFFFFFFFF
#define B2_DAI_PB19_O            0xFFFFFFFF
#define B2_DAI_PB20_O            0xFFFFFFFF
#define B2_SPORT0_CLK_O          0xFFFFFFFF
#define B2_SPORT1_CLK_O          0xFFFFFFFF
#define B2_SPORT2_CLK_O          0xFFFFFFFF
#define B2_SPORT3_CLK_O          0xFFFFFFFF
#define B2_DIR_CLK_O             0xFFFFFFFF
#define B2_DIR_TDMCLK_O          0xFFFFFFFF
#define B2_PCG_CLKA_O            0xFFFFFFFF
#define B2_PCG_CLKB_O            0xFFFFFFFF
#define B2_SPORT0_DA_O           0xFFFFFFFF
#define B2_SPORT0_DB_O           0xFFFFFFFF
#define B2_SPORT1_DA_O           0xFFFFFFFF
#define B2_SPORT1_DB_O           0xFFFFFFFF
#define B2_SPORT2_DA_O           0xFFFFFFFF
#define B2_SPORT2_DB_O           0xFFFFFFFF
#define B2_SPORT3_DA_O           0xFFFFFFFF
#define B2_SPORT3_DB_O           0xFFFFFFFF
#define B2_DIR_DAT_O             0xFFFFFFFF
#define B2_SPORT0_FS_O           0xFFFFFFFF
#define B2_SPORT1_FS_O           0xFFFFFFFF
#define B2_SPORT2_FS_O           0xFFFFFFFF
#define B2_SPORT3_FS_O           0xFFFFFFFF
#define B2_PCG_FSA_O             0xFFFFFFFF
#define B2_PCG_FSB_O             0xFFFFFFFF
#define B2_DIT_O                 0xFFFFFFFF
#define B2_DIR_FS_O              0xFFFFFFFF
#define B2_PDAP_STRB_O           0xFFFFFFFF
#define B2_SPORT0_TDV_O          0xFFFFFFFF
#define B2_SPORT1_TDV_O          0xFFFFFFFF
#define B2_SPORT2_TDV_O          0xFFFFFFFF
#define B2_SPORT3_TDV_O          0xFFFFFFFF
#define B2_DIR_LRCLK_FB_O        0xFFFFFFFF
#define B2_DIR_LRCLK_REF_O       0xFFFFFFFF
#define B2_MISCA0_O              0xFFFFFFFF
#define B2_MISCA1_O              0xFFFFFFFF
#define B2_MISCA2_O              0xFFFFFFFF
#define B2_MISCA3_O              0xFFFFFFFF
#define B2_MISCA4_O              0xFFFFFFFF
#define B2_MISCA5_O              0xFFFFFFFF
#define B2_SPORT0_CLK_PBEN_O     0xFFFFFFFF
#define B2_SPORT0_FS_PBEN_O      0xFFFFFFFF
#define B2_SPORT0_DA_PBEN_O      0xFFFFFFFF
#define B2_SPORT0_DB_PBEN_O      0xFFFFFFFF
#define B2_SPORT1_CLK_PBEN_O     0xFFFFFFFF
#define B2_SPORT1_FS_PBEN_O      0xFFFFFFFF
#define B2_SPORT1_DA_PBEN_O      0xFFFFFFFF
#define B2_SPORT1_DB_PBEN_O      0xFFFFFFFF
#define B2_SPORT2_CLK_PBEN_O     0xFFFFFFFF
#define B2_SPORT2_FS_PBEN_O      0xFFFFFFFF
#define B2_SPORT2_DA_PBEN_O      0xFFFFFFFF
#define B2_SPORT2_DB_PBEN_O      0xFFFFFFFF
#define B2_SPORT3_CLK_PBEN_O     0xFFFFFFFF
#define B2_SPORT3_FS_PBEN_O      0xFFFFFFFF
#define B2_SPORT3_DA_PBEN_O      0xFFFFFFFF
#define B2_SPORT3_DB_PBEN_O      0xFFFFFFFF
#define B2_SPORT0_TDV_PBEN_O     0xFFFFFFFF
#define B2_SPORT1_TDV_PBEN_O     0xFFFFFFFF
#define B2_SPORT2_TDV_PBEN_O     0xFFFFFFFF
#define B2_SPORT3_TDV_PBEN_O     0xFFFFFFFF
#define B2_MISC0_O               0xFFFFFFFF
#define B2_MISC1_O               0xFFFFFFFF
#define B2_MISC2_O              0xFFFFFFFF
#define B2_TIMER0_PBEN_O        0xFFFFFFFF
#define B2_TIMER1_PBEN_O        0xFFFFFFFF
#define B2_UART0_TX_PBEN_O      0xFFFFFFFF
#define B2_SPI_MISO_PBEN_O      0xFFFFFFFF
#define B2_SPI_MOSI_PBEN_O      0xFFFFFFFF
#define B2_SPI_CLK_PBEN_O       0xFFFFFFFF
#define B2_SPI_FLG0_PBEN_O      0xFFFFFFFF
#define B2_SPI_FLG1_PBEN_O      0xFFFFFFFF
#define B2_SPI_FLG2_PBEN_O      0xFFFFFFFF
#define B2_SPI_FLG3_PBEN_O      0xFFFFFFFF
#define B2_SPIB_MISO_PBEN_O     0xFFFFFFFF
#define B2_SPIB_MOSI_PBEN_O     0xFFFFFFFF
#define B2_SPIB_CLK_PBEN_O      0xFFFFFFFF
#define B2_SPIB_FLG0_PBEN_O     0xFFFFFFFF
#define B2_SPIB_FLG1_PBEN_O     0xFFFFFFFF
#define B2_SPIB_FLG2_PBEN_O     0xFFFFFFFF
#define B2_SPIB_FLG3_PBEN_O     0xFFFFFFFF
#define B2_FLAG4_PBEN_O         0xFFFFFFFF
#define B2_FLAG5_PBEN_O         0xFFFFFFFF
#define B2_FLAG6_PBEN_O         0xFFFFFFFF
#define B2_FLAG7_PBEN_O         0xFFFFFFFF
#define B2_FLAG8_PBEN_O         0xFFFFFFFF
#define B2_FLAG9_PBEN_O         0xFFFFFFFF
#define B2_FLAG10_PBEN_O        0xFFFFFFFF
#define B2_FLAG11_PBEN_O        0xFFFFFFFF
#define B2_FLAG12_PBEN_O        0xFFFFFFFF
#define B2_FLAG13_PBEN_O        0xFFFFFFFF
#define B2_FLAG14_PBEN_O        0xFFFFFFFF
#define B2_FLAG15_PBEN_O        0xFFFFFFFF
#define B2_TWI_DATA_PBEN_O      0xFFFFFFFF
#define B2_TWI_CLK_PBEN_O       0xFFFFFFFF
#define B2_MISC3_O              0xFFFFFFFF
#define B2_MISC4_O              0xFFFFFFFF
#define B2_MISC5_O              0xFFFFFFFF
#define B2_MISC6_O              0xFFFFFFFF
#define B2_MISC7_O              0xFFFFFFFF
#define B2_MISC8_O              0xFFFFFFFF





//C2 DUMMY SIGNALS
#define C2_DAI_PB01_O            0xFFFFFFFF
#define C2_DAI_PB02_O            0xFFFFFFFF
#define C2_DAI_PB03_O            0xFFFFFFFF
#define C2_DAI_PB04_O            0xFFFFFFFF
#define C2_DAI_PB05_O            0xFFFFFFFF
#define C2_DAI_PB06_O            0xFFFFFFFF
#define C2_DAI_PB07_O            0xFFFFFFFF
#define C2_DAI_PB08_O            0xFFFFFFFF
#define C2_DAI_PB09_O            0xFFFFFFFF
#define C2_DAI_PB10_O            0xFFFFFFFF
#define C2_DAI_PB11_O            0xFFFFFFFF
#define C2_DAI_PB12_O            0xFFFFFFFF
#define C2_DAI_PB13_O            0xFFFFFFFF
#define C2_DAI_PB14_O            0xFFFFFFFF
#define C2_DAI_PB15_O            0xFFFFFFFF
#define C2_DAI_PB16_O            0xFFFFFFFF
#define C2_DAI_PB17_O            0xFFFFFFFF
#define C2_DAI_PB18_O            0xFFFFFFFF
#define C2_DAI_PB19_O            0xFFFFFFFF
#define C2_DAI_PB20_O            0xFFFFFFFF
#define C2_SPORT0_CLK_O          0xFFFFFFFF
#define C2_SPORT1_CLK_O          0xFFFFFFFF
#define C2_SPORT2_CLK_O          0xFFFFFFFF
#define C2_SPORT3_CLK_O          0xFFFFFFFF
#define C2_DIR_CLK_O             0xFFFFFFFF
#define C2_DIR_TDMCLK_O          0xFFFFFFFF
#define C2_PCG_CLKA_O            0xFFFFFFFF
#define C2_PCG_CLKB_O            0xFFFFFFFF
#define C2_SPORT0_DA_O           0xFFFFFFFF
#define C2_SPORT0_DB_O           0xFFFFFFFF
#define C2_SPORT1_DA_O           0xFFFFFFFF
#define C2_SPORT1_DB_O           0xFFFFFFFF
#define C2_SPORT2_DA_O           0xFFFFFFFF
#define C2_SPORT2_DB_O           0xFFFFFFFF
#define C2_SPORT3_DA_O           0xFFFFFFFF
#define C2_SPORT3_DB_O           0xFFFFFFFF
#define C2_DIR_DAT_O             0xFFFFFFFF
#define C2_SPORT0_FS_O           0xFFFFFFFF
#define C2_SPORT1_FS_O           0xFFFFFFFF
#define C2_SPORT2_FS_O           0xFFFFFFFF
#define C2_SPORT3_FS_O           0xFFFFFFFF
#define C2_PCG_FSA_O             0xFFFFFFFF
#define C2_PCG_FSB_O             0xFFFFFFFF
#define C2_DIT_O                 0xFFFFFFFF
#define C2_DIR_FS_O              0xFFFFFFFF
#define C2_PDAP_STRB_O           0xFFFFFFFF
#define C2_SPORT0_TDV_O          0xFFFFFFFF
#define C2_SPORT1_TDV_O          0xFFFFFFFF
#define C2_SPORT2_TDV_O          0xFFFFFFFF
#define C2_SPORT3_TDV_O          0xFFFFFFFF
#define C2_DIR_LRCLK_FB_O        0xFFFFFFFF
#define C2_DIR_LRCLK_REF_O       0xFFFFFFFF
#define C2_PCG_CLKC_O            0xFFFFFFFF
#define C2_PCG_CLKD_O            0xFFFFFFFF
#define C2_PCG_FSC_O             0xFFFFFFFF
#define C2_PCG_FSD_O             0xFFFFFFFF
#define C2_MISCA0_O              0xFFFFFFFF
#define C2_MISCA1_O              0xFFFFFFFF
#define C2_MISCA2_O              0xFFFFFFFF
#define C2_MISCA3_O              0xFFFFFFFF
#define C2_MISCA4_O              0xFFFFFFFF
#define C2_MISCA5_O              0xFFFFFFFF
#define C2_SPORT0_CLK_PBEN_O     0xFFFFFFFF
#define C2_SPORT0_FS_PBEN_O      0xFFFFFFFF
#define C2_SPORT0_DA_PBEN_O      0xFFFFFFFF
#define C2_SPORT0_DB_PBEN_O      0xFFFFFFFF
#define C2_SPORT1_CLK_PBEN_O     0xFFFFFFFF
#define C2_SPORT1_FS_PBEN_O      0xFFFFFFFF
#define C2_SPORT1_DA_PBEN_O      0xFFFFFFFF
#define C2_SPORT1_DB_PBEN_O      0xFFFFFFFF
#define C2_SPORT2_CLK_PBEN_O     0xFFFFFFFF
#define C2_SPORT2_FS_PBEN_O      0xFFFFFFFF
#define C2_SPORT2_DA_PBEN_O      0xFFFFFFFF
#define C2_SPORT2_DB_PBEN_O      0xFFFFFFFF
#define C2_SPORT3_CLK_PBEN_O     0xFFFFFFFF
#define C2_SPORT3_FS_PBEN_O      0xFFFFFFFF
#define C2_SPORT3_DA_PBEN_O      0xFFFFFFFF
#define C2_SPORT3_DB_PBEN_O      0xFFFFFFFF
#define C2_SPORT0_TDV_PBEN_O     0xFFFFFFFF
#define C2_SPORT1_TDV_PBEN_O     0xFFFFFFFF
#define C2_SPORT2_TDV_PBEN_O     0xFFFFFFFF
#define C2_SPORT3_TDV_PBEN_O     0xFFFFFFFF
#define C2_DPI_PB01_O            0xFFFFFFFF
#define C2_DPI_PB02_O            0xFFFFFFFF
#define C2_DPI_PB03_O            0xFFFFFFFF
#define C2_DPI_PB04_O            0xFFFFFFFF
#define C2_DPI_PB05_O            0xFFFFFFFF
#define C2_DPI_PB06_O            0xFFFFFFFF
#define C2_DPI_PB07_O            0xFFFFFFFF
#define C2_DPI_PB08_O            0xFFFFFFFF
#define C2_DPI_PB09_O            0xFFFFFFFF
#define C2_DPI_PB10_O            0xFFFFFFFF
#define C2_DPI_PB11_O            0xFFFFFFFF
#define C2_DPI_PB12_O            0xFFFFFFFF
#define C2_DPI_PB13_O            0xFFFFFFFF
#define C2_DPI_PB14_O            0xFFFFFFFF
#define C2_UART0_TX_O            0xFFFFFFFF
#define C2_TIMER0_O              0xFFFFFFFF
#define C2_TIMER1_O              0xFFFFFFFF
#define C2_SPI_MISO_O            0xFFFFFFFF
#define C2_SPI_MOSI_O            0xFFFFFFFF
#define C2_SPI_CLK_O             0xFFFFFFFF
#define C2_SPI_FLG0_O            0xFFFFFFFF
#define C2_SPI_FLG1_O            0xFFFFFFFF
#define C2_SPI_FLG2_O            0xFFFFFFFF
#define C2_SPI_FLG3_O            0xFFFFFFFF
#define C2_FLAG4_O               0xFFFFFFFF
#define C2_FLAG5_O               0xFFFFFFFF
#define C2_FLAG6_O               0xFFFFFFFF
#define C2_FLAG7_O               0xFFFFFFFF
#define C2_FLAG8_O               0xFFFFFFFF
#define C2_FLAG9_O               0xFFFFFFFF
#define C2_FLAG10_O              0xFFFFFFFF
#define C2_FLAG11_O              0xFFFFFFFF
#define C2_FLAG12_O              0xFFFFFFFF
#define C2_FLAG13_O              0xFFFFFFFF
#define C2_FLAG14_O              0xFFFFFFFF
#define C2_FLAG15_O              0xFFFFFFFF
#define C2_SPIB_MISO_O           0xFFFFFFFF
#define C2_SPIB_MOSI_O           0xFFFFFFFF
#define C2_SPIB_CLK_O            0xFFFFFFFF
#define C2_SPIB_FLG0_O           0xFFFFFFFF
#define C2_SPIB_FLG1_O           0xFFFFFFFF
#define C2_SPIB_FLG2_O           0xFFFFFFFF
#define C2_SPIB_FLG3_O           0xFFFFFFFF

#endif //End of SRU header
